#!/usr/bin/env python

##Copyright 2009-2019 Thomas Paviot (tpaviot@gmail.com)
##
##This file is part of pythonOCC.
##
##pythonOCC is free software: you can redistribute it and/or modify
##it under the terms of the GNU Lesser General Public License as published by
##the Free Software Foundation, either version 3 of the License, or
##(at your option) any later version.
##
##pythonOCC is distributed in the hope that it will be useful,
##but WITHOUT ANY WARRANTY; without even the implied warranty of
##MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##GNU Lesser General Public License for more details.
##
##You should have received a copy of the GNU Lesser General Public License
##along with pythonOCC.  If not, see <http://www.gnu.org/licenses/>.

import ctypes
import logging
import os
import sys

from OCC.Display import OCCViewer
from OCC.Display.backend import get_qt_modules

QtCore, QtGui, QtWidgets, QtOpenGL = get_qt_modules()

# check if signal available, not available
# on PySide
HAVE_PYQT_SIGNAL = hasattr(QtCore, 'pyqtSignal')

logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
log = logging.getLogger(__name__)


class qtBaseViewer(QtOpenGL.QGLWidget):
    ''' The base Qt Widget for an OCC viewer
    '''
    def __init__(self, parent=None):
        super(qtBaseViewer, self).__init__(parent)
        self._display = OCCViewer.Viewer3d()
        self._inited = False

        # enable Mouse Tracking
        self.setMouseTracking(True)

        # Strong focus
        self.setFocusPolicy(QtCore.Qt.WheelFocus)

        self.setAttribute(QtCore.Qt.WA_NativeWindow)
        self.setAttribute(QtCore.Qt.WA_PaintOnScreen)
        self.setAttribute(QtCore.Qt.WA_NoSystemBackground)

        self.setAutoFillBackground(False)

    def GetHandle(self):
        ''' returns an the identifier of the GUI widget.
        It must be an integer
        '''
        win_id = self.winId()  # this returns either an int or voitptr
        if "%s" % type(win_id) == "<type 'PyCObject'>":  # PySide
            ### with PySide, self.winId() does not return an integer
            if sys.platform == "win32":
                ## Be careful, this hack is py27 specific
                ## does not work with python31 or higher
                ## since the PyCObject api was changed
                ctypes.pythonapi.PyCObject_AsVoidPtr.restype = ctypes.c_void_p
                ctypes.pythonapi.PyCObject_AsVoidPtr.argtypes = [ctypes.py_object]
                win_id = ctypes.pythonapi.PyCObject_AsVoidPtr(win_id)
        elif not isinstance(win_id, int):  # PyQt4 or 5
            ## below integer cast may be required because self.winId() can
            ## returns a sip.voitptr according to the PyQt version used
            ## as well as the python version
            win_id = int(win_id)
        return win_id

    def resizeEvent(self, event):
        super(qtBaseViewer, self).resizeEvent(event)
        self._display.View.MustBeResized()

    def paintEngine(self):
        return None


class qtViewer3d(qtBaseViewer):

    # emit signal when selection is changed
    # is a list of TopoDS_*
    if HAVE_PYQT_SIGNAL:
        sig_topods_selected = QtCore.pyqtSignal(list)

    def __init__(self, *kargs):
        qtBaseViewer.__init__(self, *kargs)

        self.setObjectName("qt_viewer_3d")

        self._drawbox = False
        self._zoom_area = False
        self._select_area = False
        self._inited = False
        self._leftisdown = False
        self._middleisdown = False
        self._rightisdown = False
        self._selection = None
        self._drawtext = True
        self._qApp = QtWidgets.QApplication.instance()
        self._key_map = {}
        self._current_cursor = "arrow"
        self._available_cursors = {}

    @property
    def qApp(self):
        # reference to QApplication instance
        return self._qApp

    @qApp.setter
    def qApp(self, value):
        self._qApp = value

    def InitDriver(self):
        self._display.Create(window_handle=self.GetHandle(), parent=self)
        # background gradient
        self._display.SetModeShaded()
        self._inited = True
        # dict mapping keys to functions
        self._key_map = {ord('W'): self._display.SetModeWireFrame,
                         ord('S'): self._display.SetModeShaded,
                         ord('A'): self._display.EnableAntiAliasing,
                         ord('B'): self._display.DisableAntiAliasing,
                         ord('H'): self._display.SetModeHLR,
                         ord('F'): self._display.FitAll,
                         ord('G'): self._display.SetSelectionMode}
        self.createCursors()

    def createCursors(self):
        module_pth = os.path.abspath(os.path.dirname(__file__))
        icon_pth = os.path.join(module_pth, "icons")

        _CURSOR_PIX_ROT = QtGui.QPixmap(os.path.join(icon_pth, "cursor-rotate.png"))
        _CURSOR_PIX_PAN = QtGui.QPixmap(os.path.join(icon_pth, "cursor-pan.png"))
        _CURSOR_PIX_ZOOM = QtGui.QPixmap(os.path.join(icon_pth, "cursor-magnify.png"))
        _CURSOR_PIX_ZOOM_AREA = QtGui.QPixmap(os.path.join(icon_pth, "cursor-magnify-area.png"))

        self._available_cursors = {
            "arrow": QtGui.QCursor(QtCore.Qt.ArrowCursor),  # default
            "pan": QtGui.QCursor(_CURSOR_PIX_PAN),
            "rotate": QtGui.QCursor(_CURSOR_PIX_ROT),
            "zoom": QtGui.QCursor(_CURSOR_PIX_ZOOM),
            "zoom-area": QtGui.QCursor(_CURSOR_PIX_ZOOM_AREA),
        }

        self._current_cursor = "arrow"

    def keyPressEvent(self, event):
        code = event.key()
        if code in self._key_map:
            self._key_map[code]()
        elif code in range(256):
            log.info('key: "%s"(code %i) not mapped to any function' % (chr(code), code))
        else:
            log.info('key: code %i not mapped to any function' % code)

    def focusInEvent(self, event):
        if self._inited:
            self._display.Repaint()

    def focusOutEvent(self, event):
        if self._inited:
            self._display.Repaint()

    def paintEvent(self, event):
        if not self._inited:
            self.InitDriver()

        self._display.Context.UpdateCurrentViewer()

        if self._drawbox:
            painter = QtGui.QPainter(self)
            painter.setPen(QtGui.QPen(QtGui.QColor(0, 0, 0), 2))
            rect = QtCore.QRect(*self._drawbox)
            painter.drawRect(rect)

    def wheelEvent(self, event):
        try:  # PyQt4/PySide
            delta = event.delta()
        except:  # PyQt5
            delta = event.angleDelta().y()
        if delta > 0:
            zoom_factor = 2.
        else:
            zoom_factor = 0.5
        self._display.ZoomFactor(zoom_factor)

    @property
    def cursor(self):
        return self._current_cursor

    @cursor.setter
    def cursor(self, value):
        if not self._current_cursor == value:

            self._current_cursor = value
            cursor = self._available_cursors.get(value)

            if cursor:
                self.qApp.setOverrideCursor(cursor)
            else:
                self.qApp.restoreOverrideCursor()

    def mousePressEvent(self, event):
        self.setFocus()
        ev = event.pos()
        self.dragStartPosX = ev.x()
        self.dragStartPosY = ev.y()
        self._display.StartRotation(self.dragStartPosX, self.dragStartPosY)

    def mouseReleaseEvent(self, event):
        pt = event.pos()
        modifiers = event.modifiers()

        if event.button() == QtCore.Qt.LeftButton:
            if self._select_area:
                [Xmin, Ymin, dx, dy] = self._drawbox
                self._display.SelectArea(Xmin, Ymin, Xmin + dx, Ymin + dy)
                self._select_area = False
            else:
                # multiple select if shift is pressed
                if modifiers == QtCore.Qt.ShiftModifier:
                    self._display.ShiftSelect(pt.x(), pt.y())
                else:
                    # single select otherwise
                    self._display.Select(pt.x(), pt.y())

                    if (self._display.selected_shapes is not None) and HAVE_PYQT_SIGNAL:
                        self.sig_topods_selected.emit(self._display.selected_shapes)


        elif event.button() == QtCore.Qt.RightButton:
            if self._zoom_area:
                [Xmin, Ymin, dx, dy] = self._drawbox
                self._display.ZoomArea(Xmin, Ymin, Xmin + dx, Ymin + dy)
                self._zoom_area = False

        self.cursor = "arrow"

    def DrawBox(self, event):
        tolerance = 2
        pt = event.pos()
        dx = pt.x() - self.dragStartPosX
        dy = pt.y() - self.dragStartPosY
        if abs(dx) <= tolerance and abs(dy) <= tolerance:
            return
        self._drawbox = [self.dragStartPosX, self.dragStartPosY, dx, dy]


    def mouseMoveEvent(self, evt):
        pt = evt.pos()
        buttons = int(evt.buttons())
        modifiers = evt.modifiers()
        # ROTATE
        if (buttons == QtCore.Qt.LeftButton and
                not modifiers == QtCore.Qt.ShiftModifier):
            self.cursor = "rotate"
            self._display.Rotation(pt.x(), pt.y())
            self._drawbox = False
        # DYNAMIC ZOOM
        elif (buttons == QtCore.Qt.RightButton and
              not modifiers == QtCore.Qt.ShiftModifier):
            self.cursor = "zoom"
            self._display.Repaint()
            self._display.DynamicZoom(abs(self.dragStartPosX),
                                      abs(self.dragStartPosY), abs(pt.x()),
                                      abs(pt.y()))
            self.dragStartPosX = pt.x()
            self.dragStartPosY = pt.y()
            self._drawbox = False
        # PAN
        elif buttons == QtCore.Qt.MidButton:
            dx = pt.x() - self.dragStartPosX
            dy = pt.y() - self.dragStartPosY
            self.dragStartPosX = pt.x()
            self.dragStartPosY = pt.y()
            self.cursor = "pan"
            self._display.Pan(dx, -dy)
            self._drawbox = False
        # DRAW BOX
        # ZOOM WINDOW
        elif (buttons == QtCore.Qt.RightButton and
              modifiers == QtCore.Qt.ShiftModifier):
            self._zoom_area = True
            self.cursor = "zoom-area"
            self.DrawBox(evt)
            self.update()
        # SELECT AREA
        elif (buttons == QtCore.Qt.LeftButton and
              modifiers == QtCore.Qt.ShiftModifier):
            self._select_area = True
            self.DrawBox(evt)
            self.update()
        else:
            self._drawbox = False
            self._display.MoveTo(pt.x(), pt.y())
            self.cursor = "arrow"



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.CDM import *
from OCC.Core.TCollection import *
from OCC.Core.PCDM import *
from OCC.Core.Message import *


class CDF_TypeOfActivation(IntEnum):
	CDF_TOA_New: int = ...
	CDF_TOA_Modified: int = ...
	CDF_TOA_Unchanged: int = ...
CDF_TOA_New = CDF_TypeOfActivation.CDF_TOA_New
CDF_TOA_Modified = CDF_TypeOfActivation.CDF_TOA_Modified
CDF_TOA_Unchanged = CDF_TypeOfActivation.CDF_TOA_Unchanged

class CDF_TryStoreStatus(IntEnum):
	CDF_TS_OK: int = ...
	CDF_TS_NoCurrentDocument: int = ...
	CDF_TS_NoDriver: int = ...
	CDF_TS_NoSubComponentDriver: int = ...
CDF_TS_OK = CDF_TryStoreStatus.CDF_TS_OK
CDF_TS_NoCurrentDocument = CDF_TryStoreStatus.CDF_TS_NoCurrentDocument
CDF_TS_NoDriver = CDF_TryStoreStatus.CDF_TS_NoDriver
CDF_TS_NoSubComponentDriver = CDF_TryStoreStatus.CDF_TS_NoSubComponentDriver

class CDF_SubComponentStatus(IntEnum):
	CDF_SCS_Consistent: int = ...
	CDF_SCS_Unconsistent: int = ...
	CDF_SCS_Stored: int = ...
	CDF_SCS_Modified: int = ...
CDF_SCS_Consistent = CDF_SubComponentStatus.CDF_SCS_Consistent
CDF_SCS_Unconsistent = CDF_SubComponentStatus.CDF_SCS_Unconsistent
CDF_SCS_Stored = CDF_SubComponentStatus.CDF_SCS_Stored
CDF_SCS_Modified = CDF_SubComponentStatus.CDF_SCS_Modified

class CDF_StoreSetNameStatus(IntEnum):
	CDF_SSNS_OK: int = ...
	CDF_SSNS_ReplacingAnExistentDocument: int = ...
	CDF_SSNS_OpenDocument: int = ...
CDF_SSNS_OK = CDF_StoreSetNameStatus.CDF_SSNS_OK
CDF_SSNS_ReplacingAnExistentDocument = CDF_StoreSetNameStatus.CDF_SSNS_ReplacingAnExistentDocument
CDF_SSNS_OpenDocument = CDF_StoreSetNameStatus.CDF_SSNS_OpenDocument

class CDF_Application(CDM_Application):
	def CanClose(self, aDocument: CDM_Document) -> CDM_CanCloseStatus: ...
	@overload
	def CanRetrieve(self, aFolder: TCollection_ExtendedString, aName: TCollection_ExtendedString) -> PCDM_ReaderStatus: ...
	@overload
	def CanRetrieve(self, aFolder: TCollection_ExtendedString, aName: TCollection_ExtendedString, aVersion: TCollection_ExtendedString) -> PCDM_ReaderStatus: ...
	def Close(self, aDocument: CDM_Document) -> None: ...
	def DefaultFolder(self) -> Standard_ExtString: ...
	def Format(self, aFileName: TCollection_ExtendedString, theFormat: TCollection_ExtendedString) -> bool: ...
	def GetRetrieveStatus(self) -> PCDM_ReaderStatus: ...
	@staticmethod
	def Load(aGUID: Standard_GUID) -> CDF_Application: ...
	def MetaDataDriver(self) -> CDF_MetaDataDriver: ...
	def Open(self, aDocument: CDM_Document) -> None: ...
	def ReaderFromFormat(self, aFormat: TCollection_ExtendedString) -> PCDM_Reader: ...
	@overload
	def Retrieve(self, aFolder: TCollection_ExtendedString, aName: TCollection_ExtendedString, UseStorageConfiguration: Optional[bool] = True, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> CDM_Document: ...
	@overload
	def Retrieve(self, aFolder: TCollection_ExtendedString, aName: TCollection_ExtendedString, aVersion: TCollection_ExtendedString, UseStorageConfiguration: Optional[bool] = True, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> CDM_Document: ...
	def SetDefaultFolder(self, aFolder: Standard_ExtString) -> bool: ...
	def WriterFromFormat(self, aFormat: TCollection_ExtendedString) -> PCDM_StorageDriver: ...

class CDF_Directory(Standard_Transient):
	def __init__(self) -> None: ...
	def Add(self, aDocument: CDM_Document) -> None: ...
	def Contains(self, aDocument: CDM_Document) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def Last(self) -> CDM_Document: ...
	def Length(self) -> int: ...
	def Remove(self, aDocument: CDM_Document) -> None: ...

class CDF_MetaDataDriver(Standard_Transient):
	def BuildFileName(self, aDocument: CDM_Document) -> TCollection_ExtendedString: ...
	def CreateDependsOn(self, aFirstData: CDM_MetaData, aSecondData: CDM_MetaData) -> None: ...
	def CreateMetaData(self, aDocument: CDM_Document, aFileName: TCollection_ExtendedString) -> CDM_MetaData: ...
	def CreateReference(self, aFrom: CDM_MetaData, aTo: CDM_MetaData, aReferenceIdentifier: int, aToDocumentVersion: int) -> None: ...
	def DefaultFolder(self) -> TCollection_ExtendedString: ...
	@overload
	def Find(self, aFolder: TCollection_ExtendedString, aName: TCollection_ExtendedString, aVersion: TCollection_ExtendedString) -> bool: ...
	@overload
	def Find(self, aFolder: TCollection_ExtendedString, aName: TCollection_ExtendedString) -> bool: ...
	def FindFolder(self, aFolder: TCollection_ExtendedString) -> bool: ...
	def HasReadPermission(self, aFolder: TCollection_ExtendedString, aName: TCollection_ExtendedString, aVersion: TCollection_ExtendedString) -> bool: ...
	def HasVersion(self, aFolder: TCollection_ExtendedString, aName: TCollection_ExtendedString) -> bool: ...
	def HasVersionCapability(self) -> bool: ...
	def LastVersion(self, aMetaData: CDM_MetaData) -> CDM_MetaData: ...
	@overload
	def MetaData(self, aFolder: TCollection_ExtendedString, aName: TCollection_ExtendedString, aVersion: TCollection_ExtendedString) -> CDM_MetaData: ...
	@overload
	def MetaData(self, aFolder: TCollection_ExtendedString, aName: TCollection_ExtendedString) -> CDM_MetaData: ...
	def ReferenceIterator(self, theMessageDriver: Message_Messenger) -> PCDM_ReferenceIterator: ...
	def SetName(self, aDocument: CDM_Document, aName: TCollection_ExtendedString) -> TCollection_ExtendedString: ...

class CDF_MetaDataDriverFactory(Standard_Transient):
	def Build(self) -> CDF_MetaDataDriver: ...

class CDF_Store:
	def __init__(self, aDocument: CDM_Document) -> None: ...
	def AssociatedStatusText(self) -> Standard_ExtString: ...
	def Comment(self) -> TCollection_HExtendedString: ...
	def CurrentIsConsistent(self) -> bool: ...
	def Description(self) -> TCollection_HExtendedString: ...
	def Folder(self) -> TCollection_HExtendedString: ...
	def HasAPreviousVersion(self) -> bool: ...
	def IsConsistent(self) -> bool: ...
	def IsMainDocument(self) -> bool: ...
	def IsModified(self) -> bool: ...
	def IsStored(self) -> bool: ...
	def MetaDataPath(self) -> TCollection_HExtendedString: ...
	def Name(self) -> TCollection_HExtendedString: ...
	def Path(self) -> Standard_ExtString: ...
	def PreviousVersion(self) -> TCollection_HExtendedString: ...
	def Realize(self, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def RecheckName(self) -> CDF_StoreSetNameStatus: ...
	def SetComment(self, aComment: Standard_ExtString) -> None: ...
	def SetCurrent(self, aPresentation: Standard_ExtString) -> None: ...
	@overload
	def SetFolder(self, aFolder: TCollection_ExtendedString) -> bool: ...
	@overload
	def SetFolder(self, aFolder: Standard_ExtString) -> bool: ...
	def SetMain(self) -> None: ...
	@overload
	def SetName(self, aName: Standard_ExtString) -> CDF_StoreSetNameStatus: ...
	@overload
	def SetName(self, aName: TCollection_ExtendedString) -> CDF_StoreSetNameStatus: ...
	def SetPreviousVersion(self, aPreviousVersion: Standard_ExtString) -> bool: ...
	def StoreStatus(self) -> PCDM_StoreStatus: ...

class CDF_StoreList(Standard_Transient):
	def __init__(self, aDocument: CDM_Document) -> None: ...
	def Init(self) -> None: ...
	def IsConsistent(self) -> bool: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Store(self, aMetaData: CDM_MetaData, aStatusAssociatedText: TCollection_ExtendedString, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> PCDM_StoreStatus: ...
	def Value(self) -> CDM_Document: ...

class CDF_FWOSDriver(CDF_MetaDataDriver):
	def __init__(self, theLookUpTable: CDM_MetaDataLookUpTable) -> None: ...
	def BuildFileName(self, aDocument: CDM_Document) -> TCollection_ExtendedString: ...
	def DefaultFolder(self) -> TCollection_ExtendedString: ...
	def Find(self, aFolder: TCollection_ExtendedString, aName: TCollection_ExtendedString, aVersion: TCollection_ExtendedString) -> bool: ...
	def FindFolder(self, aFolder: TCollection_ExtendedString) -> bool: ...
	def HasReadPermission(self, aFolder: TCollection_ExtendedString, aName: TCollection_ExtendedString, aVersion: TCollection_ExtendedString) -> bool: ...
	def SetName(self, aDocument: CDM_Document, aName: TCollection_ExtendedString) -> TCollection_ExtendedString: ...

#classnotwrapped
class CDF_DirectoryIterator: ...

# harray1 classes
# harray2 classes
# hsequence classes

CDF_Application_Load = CDF_Application.Load



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColgp import *
from OCC.Core.TColStd import *
from OCC.Core.GeomAbs import *
from OCC.Core.math import *


class plib:
	@staticmethod
	def Bin(N: int, P: int) -> float: ...
	@overload
	@staticmethod
	def CoefficientsPoles(Coefs: TColgp_Array1OfPnt, WCoefs: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt, WPoles: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def CoefficientsPoles(Coefs: TColgp_Array1OfPnt2d, WCoefs: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt2d, WPoles: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def CoefficientsPoles(Coefs: TColStd_Array1OfReal, WCoefs: TColStd_Array1OfReal, Poles: TColStd_Array1OfReal, WPoles: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def CoefficientsPoles(dim: int, Coefs: TColStd_Array1OfReal, WCoefs: TColStd_Array1OfReal, Poles: TColStd_Array1OfReal, WPoles: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def CoefficientsPoles(Coefs: TColgp_Array2OfPnt, WCoefs: TColStd_Array2OfReal, Poles: TColgp_Array2OfPnt, WPoles: TColStd_Array2OfReal) -> None: ...
	@staticmethod
	def ConstraintOrder(NivConstr: int) -> GeomAbs_Shape: ...
	@staticmethod
	def EvalCubicHermite(U: float, DerivativeOrder: int, Dimension: int) -> Tuple[int, float, float, float, float]: ...
	@staticmethod
	def EvalLagrange(U: float, DerivativeOrder: int, Degree: int, Dimension: int) -> Tuple[int, float, float, float]: ...
	@overload
	@staticmethod
	def EvalLength(Degree: int, Dimension: int, U1: float, U2: float) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def EvalLength(Degree: int, Dimension: int, U1: float, U2: float, Tol: float) -> Tuple[float, float, float]: ...
	@staticmethod
	def EvalPoly2Var(U: float, V: float, UDerivativeOrder: int, VDerivativeOrder: int, UDegree: int, VDegree: int, Dimension: int) -> Tuple[float, float]: ...
	@staticmethod
	def EvalPolynomial(U: float, DerivativeOrder: int, Degree: int, Dimension: int) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def GetPoles(FP: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt) -> None: ...
	@overload
	@staticmethod
	def GetPoles(FP: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def GetPoles(FP: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt2d) -> None: ...
	@overload
	@staticmethod
	def GetPoles(FP: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal) -> None: ...
	@staticmethod
	def HermiteCoefficients(FirstParameter: float, LastParameter: float, FirstOrder: int, LastOrder: int, MatrixCoefs: math_Matrix) -> bool: ...
	@staticmethod
	def HermiteInterpolate(Dimension: int, FirstParameter: float, LastParameter: float, FirstOrder: int, LastOrder: int, FirstConstr: TColStd_Array2OfReal, LastConstr: TColStd_Array2OfReal, Coefficients: TColStd_Array1OfReal) -> bool: ...
	@staticmethod
	def JacobiParameters(ConstraintOrder: GeomAbs_Shape, MaxDegree: int, Code: int) -> Tuple[int, int]: ...
	@staticmethod
	def NivConstr(ConstraintOrder: GeomAbs_Shape) -> int: ...
	@staticmethod
	def NoDerivativeEvalPolynomial(U: float, Degree: int, Dimension: int, DegreeDimension: int) -> Tuple[float, float]: ...
	@staticmethod
	def NoWeights() -> TColStd_Array1OfReal: ...
	@staticmethod
	def NoWeights2() -> TColStd_Array2OfReal: ...
	@staticmethod
	def RationalDerivative(Degree: int, N: int, Dimension: int, All: Optional[bool] = True) -> Tuple[float, float]: ...
	@staticmethod
	def RationalDerivatives(DerivativesRequest: int, Dimension: int) -> Tuple[float, float, float]: ...
	@overload
	@staticmethod
	def SetPoles(Poles: TColgp_Array1OfPnt, FP: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def SetPoles(Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, FP: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def SetPoles(Poles: TColgp_Array1OfPnt2d, FP: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def SetPoles(Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, FP: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def Trimming(U1: float, U2: float, Coeffs: TColgp_Array1OfPnt, WCoeffs: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def Trimming(U1: float, U2: float, Coeffs: TColgp_Array1OfPnt2d, WCoeffs: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def Trimming(U1: float, U2: float, Coeffs: TColStd_Array1OfReal, WCoeffs: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def Trimming(U1: float, U2: float, dim: int, Coeffs: TColStd_Array1OfReal, WCoeffs: TColStd_Array1OfReal) -> None: ...
	@staticmethod
	def UTrimming(U1: float, U2: float, Coeffs: TColgp_Array2OfPnt, WCoeffs: TColStd_Array2OfReal) -> None: ...
	@staticmethod
	def VTrimming(V1: float, V2: float, Coeffs: TColgp_Array2OfPnt, WCoeffs: TColStd_Array2OfReal) -> None: ...

class PLib_Base(Standard_Transient):
	def D0(self, U: float, BasisValue: TColStd_Array1OfReal) -> None: ...
	def D1(self, U: float, BasisValue: TColStd_Array1OfReal, BasisD1: TColStd_Array1OfReal) -> None: ...
	def D2(self, U: float, BasisValue: TColStd_Array1OfReal, BasisD1: TColStd_Array1OfReal, BasisD2: TColStd_Array1OfReal) -> None: ...
	def D3(self, U: float, BasisValue: TColStd_Array1OfReal, BasisD1: TColStd_Array1OfReal, BasisD2: TColStd_Array1OfReal, BasisD3: TColStd_Array1OfReal) -> None: ...
	def ReduceDegree(self, Dimension: int, MaxDegree: int, Tol: float) -> Tuple[float, int, float]: ...
	def ToCoefficients(self, Dimension: int, Degree: int, CoeffinBase: TColStd_Array1OfReal, Coefficients: TColStd_Array1OfReal) -> None: ...
	def WorkDegree(self) -> int: ...

class PLib_DoubleJacobiPolynomial:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, JacPolU: PLib_JacobiPolynomial, JacPolV: PLib_JacobiPolynomial) -> None: ...
	def AverageError(self, Dimension: int, DegreeU: int, DegreeV: int, dJacCoeff: int, JacCoeff: TColStd_Array1OfReal) -> float: ...
	def MaxError(self, Dimension: int, MinDegreeU: int, MaxDegreeU: int, MinDegreeV: int, MaxDegreeV: int, dJacCoeff: int, JacCoeff: TColStd_Array1OfReal, Error: float) -> float: ...
	def MaxErrorU(self, Dimension: int, DegreeU: int, DegreeV: int, dJacCoeff: int, JacCoeff: TColStd_Array1OfReal) -> float: ...
	def MaxErrorV(self, Dimension: int, DegreeU: int, DegreeV: int, dJacCoeff: int, JacCoeff: TColStd_Array1OfReal) -> float: ...
	def ReduceDegree(self, Dimension: int, MinDegreeU: int, MaxDegreeU: int, MinDegreeV: int, MaxDegreeV: int, dJacCoeff: int, JacCoeff: TColStd_Array1OfReal, EpmsCut: float) -> Tuple[float, int, int]: ...
	def TabMaxU(self) -> TColStd_HArray1OfReal: ...
	def TabMaxV(self) -> TColStd_HArray1OfReal: ...
	def U(self) -> PLib_JacobiPolynomial: ...
	def V(self) -> PLib_JacobiPolynomial: ...
	def WDoubleJacobiToCoefficients(self, Dimension: int, DegreeU: int, DegreeV: int, JacCoeff: TColStd_Array1OfReal, Coefficients: TColStd_Array1OfReal) -> None: ...

class PLib_HermitJacobi(PLib_Base):
	def __init__(self, WorkDegree: int, ConstraintOrder: GeomAbs_Shape) -> None: ...
	def AverageError(self, Dimension: int, NewDegree: int) -> Tuple[float, float]: ...
	def D0(self, U: float, BasisValue: TColStd_Array1OfReal) -> None: ...
	def D1(self, U: float, BasisValue: TColStd_Array1OfReal, BasisD1: TColStd_Array1OfReal) -> None: ...
	def D2(self, U: float, BasisValue: TColStd_Array1OfReal, BasisD1: TColStd_Array1OfReal, BasisD2: TColStd_Array1OfReal) -> None: ...
	def D3(self, U: float, BasisValue: TColStd_Array1OfReal, BasisD1: TColStd_Array1OfReal, BasisD2: TColStd_Array1OfReal, BasisD3: TColStd_Array1OfReal) -> None: ...
	def MaxError(self, Dimension: int, NewDegree: int) -> Tuple[float, float]: ...
	def NivConstr(self) -> int: ...
	def ReduceDegree(self, Dimension: int, MaxDegree: int, Tol: float) -> Tuple[float, int, float]: ...
	def ToCoefficients(self, Dimension: int, Degree: int, HermJacCoeff: TColStd_Array1OfReal, Coefficients: TColStd_Array1OfReal) -> None: ...
	def WorkDegree(self) -> int: ...

class PLib_JacobiPolynomial(PLib_Base):
	def __init__(self, WorkDegree: int, ConstraintOrder: GeomAbs_Shape) -> None: ...
	def AverageError(self, Dimension: int, NewDegree: int) -> Tuple[float, float]: ...
	def D0(self, U: float, BasisValue: TColStd_Array1OfReal) -> None: ...
	def D1(self, U: float, BasisValue: TColStd_Array1OfReal, BasisD1: TColStd_Array1OfReal) -> None: ...
	def D2(self, U: float, BasisValue: TColStd_Array1OfReal, BasisD1: TColStd_Array1OfReal, BasisD2: TColStd_Array1OfReal) -> None: ...
	def D3(self, U: float, BasisValue: TColStd_Array1OfReal, BasisD1: TColStd_Array1OfReal, BasisD2: TColStd_Array1OfReal, BasisD3: TColStd_Array1OfReal) -> None: ...
	def MaxError(self, Dimension: int, NewDegree: int) -> Tuple[float, float]: ...
	def MaxValue(self, TabMax: TColStd_Array1OfReal) -> None: ...
	def NivConstr(self) -> int: ...
	def Points(self, NbGaussPoints: int, TabPoints: TColStd_Array1OfReal) -> None: ...
	def ReduceDegree(self, Dimension: int, MaxDegree: int, Tol: float) -> Tuple[float, int, float]: ...
	def ToCoefficients(self, Dimension: int, Degree: int, JacCoeff: TColStd_Array1OfReal, Coefficients: TColStd_Array1OfReal) -> None: ...
	def Weights(self, NbGaussPoints: int, TabWeights: TColStd_Array2OfReal) -> None: ...
	def WorkDegree(self) -> int: ...

# harray1 classes
# harray2 classes
# hsequence classes

plib_Bin = plib.Bin
plib_CoefficientsPoles = plib.CoefficientsPoles
plib_CoefficientsPoles = plib.CoefficientsPoles
plib_CoefficientsPoles = plib.CoefficientsPoles
plib_CoefficientsPoles = plib.CoefficientsPoles
plib_CoefficientsPoles = plib.CoefficientsPoles
plib_ConstraintOrder = plib.ConstraintOrder
plib_EvalCubicHermite = plib.EvalCubicHermite
plib_EvalLagrange = plib.EvalLagrange
plib_EvalLength = plib.EvalLength
plib_EvalLength = plib.EvalLength
plib_EvalPoly2Var = plib.EvalPoly2Var
plib_EvalPolynomial = plib.EvalPolynomial
plib_GetPoles = plib.GetPoles
plib_GetPoles = plib.GetPoles
plib_GetPoles = plib.GetPoles
plib_GetPoles = plib.GetPoles
plib_HermiteCoefficients = plib.HermiteCoefficients
plib_HermiteInterpolate = plib.HermiteInterpolate
plib_JacobiParameters = plib.JacobiParameters
plib_NivConstr = plib.NivConstr
plib_NoDerivativeEvalPolynomial = plib.NoDerivativeEvalPolynomial
plib_NoWeights = plib.NoWeights
plib_NoWeights2 = plib.NoWeights2
plib_RationalDerivative = plib.RationalDerivative
plib_RationalDerivatives = plib.RationalDerivatives
plib_SetPoles = plib.SetPoles
plib_SetPoles = plib.SetPoles
plib_SetPoles = plib.SetPoles
plib_SetPoles = plib.SetPoles
plib_Trimming = plib.Trimming
plib_Trimming = plib.Trimming
plib_Trimming = plib.Trimming
plib_Trimming = plib.Trimming
plib_UTrimming = plib.UTrimming
plib_VTrimming = plib.VTrimming



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *


class TopClass_SolidExplorer:
	def CurrentFace(self) -> TopoDS_Face: ...
	def InitFace(self) -> None: ...
	def InitShell(self) -> None: ...
	def MoreFaces(self) -> bool: ...
	def MoreShells(self) -> bool: ...
	def NextFace(self) -> None: ...
	def NextShell(self) -> None: ...
	def OtherSegment(self, P: gp_Pnt, L: gp_Lin) -> float: ...
	def Reject(self, P: gp_Pnt) -> bool: ...
	def RejectFace(self, L: gp_Lin, Par: float) -> bool: ...
	def RejectShell(self, L: gp_Lin, Par: float) -> bool: ...
	def Segment(self, P: gp_Pnt, L: gp_Lin) -> float: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.IMeshTools import *
from OCC.Core.Message import *
from OCC.Core.gp import *
from OCC.Core.TopAbs import *
from OCC.Core.TopoDS import *
from OCC.Core.GeomAbs import *
from OCC.Core.TCollection import *
from OCC.Core.TColStd import *
from OCC.Core.BRepAdaptor import *
from OCC.Core.Adaptor3d import *
from OCC.Core.Poly import *
from OCC.Core.Bnd import *
from OCC.Core.TopLoc import *
from OCC.Core.Geom2d import *
from OCC.Core.Geom import *
from OCC.Core.IMeshData import *


class BRepMesh_FactoryError(IntEnum):
	BRepMesh_FE_NOERROR: int = ...
	BRepMesh_FE_LIBRARYNOTFOUND: int = ...
	BRepMesh_FE_FUNCTIONNOTFOUND: int = ...
	BRepMesh_FE_CANNOTCREATEALGO: int = ...
BRepMesh_FE_NOERROR = BRepMesh_FactoryError.BRepMesh_FE_NOERROR
BRepMesh_FE_LIBRARYNOTFOUND = BRepMesh_FactoryError.BRepMesh_FE_LIBRARYNOTFOUND
BRepMesh_FE_FUNCTIONNOTFOUND = BRepMesh_FactoryError.BRepMesh_FE_FUNCTIONNOTFOUND
BRepMesh_FE_CANNOTCREATEALGO = BRepMesh_FactoryError.BRepMesh_FE_CANNOTCREATEALGO

class BRepMesh_DegreeOfFreedom(IntEnum):
	BRepMesh_Free: int = ...
	BRepMesh_InVolume: int = ...
	BRepMesh_OnSurface: int = ...
	BRepMesh_OnCurve: int = ...
	BRepMesh_Fixed: int = ...
	BRepMesh_Frontier: int = ...
	BRepMesh_Deleted: int = ...
BRepMesh_Free = BRepMesh_DegreeOfFreedom.BRepMesh_Free
BRepMesh_InVolume = BRepMesh_DegreeOfFreedom.BRepMesh_InVolume
BRepMesh_OnSurface = BRepMesh_DegreeOfFreedom.BRepMesh_OnSurface
BRepMesh_OnCurve = BRepMesh_DegreeOfFreedom.BRepMesh_OnCurve
BRepMesh_Fixed = BRepMesh_DegreeOfFreedom.BRepMesh_Fixed
BRepMesh_Frontier = BRepMesh_DegreeOfFreedom.BRepMesh_Frontier
BRepMesh_Deleted = BRepMesh_DegreeOfFreedom.BRepMesh_Deleted

class BRepMesh_BaseMeshAlgo(IMeshTools_MeshAlgo):
	pass

class BRepMesh_Circle:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theLocation: gp_XY, theRadius: float) -> None: ...
	def Location(self) -> gp_XY: ...
	def Radius(self) -> float: ...
	def SetLocation(self, theLocation: gp_XY) -> None: ...
	def SetRadius(self, theRadius: float) -> None: ...

class BRepMesh_CircleInspector(NCollection_CellFilter_InspectorXY):
	def __init__(self, theTolerance: float, theReservedSize: int, theAllocator: NCollection_IncAllocator) -> None: ...
	def Bind(self, theIndex: int, theCircle: BRepMesh_Circle) -> None: ...
	def Circle(self, theIndex: int) -> BRepMesh_Circle: ...
	def Circles(self) -> False: ...
	def GetShotCircles(self) -> False: ...
	def Inspect(self, theTargetIndex: int) -> NCollection_CellFilter_Action: ...
	@staticmethod
	def IsEqual(theIndex: int, theTargetIndex: int) -> bool: ...
	def SetPoint(self, thePoint: gp_XY) -> None: ...

class BRepMesh_CircleTool:
	@overload
	def __init__(self, theAllocator: NCollection_IncAllocator) -> None: ...
	@overload
	def __init__(self, theReservedSize: int, theAllocator: NCollection_IncAllocator) -> None: ...
	@overload
	def Bind(self, theIndex: int, theCircle: gp_Circ2d) -> None: ...
	@overload
	def Bind(self, theIndex: int, thePoint1: gp_XY, thePoint2: gp_XY, thePoint3: gp_XY) -> bool: ...
	def Delete(self, theIndex: int) -> None: ...
	def IsEmpty(self) -> bool: ...
	@staticmethod
	def MakeCircle(thePoint1: gp_XY, thePoint2: gp_XY, thePoint3: gp_XY, theLocation: gp_XY) -> Tuple[bool, float]: ...
	def MocBind(self, theIndex: int) -> None: ...
	def Select(self, thePoint: gp_XY) -> False: ...
	@overload
	def SetCellSize(self, theSize: float) -> None: ...
	@overload
	def SetCellSize(self, theSizeX: float, theSizeY: float) -> None: ...
	def SetMinMaxSize(self, theMin: gp_XY, theMax: gp_XY) -> None: ...

class BRepMesh_Classifier(Standard_Transient):
	def __init__(self) -> None: ...
	def Perform(self, thePoint: gp_Pnt2d) -> TopAbs_State: ...

class BRepMesh_Context(IMeshTools_Context):
	def __init__(self, theMeshType: Optional[IMeshTools_MeshAlgoType] = IMeshTools_MeshAlgoType_DEFAULT) -> None: ...

class BRepMesh_CurveTessellator(IMeshTools_CurveTessellator):
	def PointsNb(self) -> int: ...
	def Value(self, theIndex: int, thePoint: gp_Pnt) -> Tuple[bool, float]: ...

class BRepMesh_DataStructureOfDelaun(Standard_Transient):
	def __init__(self, theAllocator: NCollection_IncAllocator, theReservedNodeSize: Optional[int] = 100) -> None: ...
	def AddElement(self, theElement: BRepMesh_Triangle) -> int: ...
	def AddLink(self, theLink: BRepMesh_Edge) -> int: ...
	def AddNode(self, theNode: BRepMesh_Vertex, isForceAdd: Optional[bool] = False) -> int: ...
	def Allocator(self) -> NCollection_IncAllocator: ...
	def ClearDeleted(self) -> None: ...
	def ClearDomain(self) -> None: ...
	def Data(self) -> BRepMesh_VertexTool: ...
	def Dump(self, theFileNameStr: str) -> None: ...
	def ElementsConnectedTo(self, theLinkIndex: int) -> BRepMesh_PairOfIndex: ...
	def ElementsOfDomain(self) -> False: ...
	def GetElement(self, theIndex: int) -> BRepMesh_Triangle: ...
	def GetLink(self, theIndex: int) -> BRepMesh_Edge: ...
	def GetNode(self, theIndex: int) -> BRepMesh_Vertex: ...
	@overload
	def IndexOf(self, theNode: BRepMesh_Vertex) -> int: ...
	@overload
	def IndexOf(self, theLink: BRepMesh_Edge) -> int: ...
	def LinksConnectedTo(self, theIndex: int) -> False: ...
	def LinksOfDomain(self) -> False: ...
	def NbElements(self) -> int: ...
	def NbLinks(self) -> int: ...
	def NbNodes(self) -> int: ...
	def RemoveElement(self, theIndex: int) -> None: ...
	def RemoveLink(self, theIndex: int, isForce: Optional[bool] = False) -> None: ...
	def RemoveNode(self, theIndex: int, isForce: Optional[bool] = False) -> None: ...
	def SubstituteElement(self, theIndex: int, theNewElement: BRepMesh_Triangle) -> bool: ...
	def SubstituteLink(self, theIndex: int, theNewLink: BRepMesh_Edge) -> bool: ...
	def SubstituteNode(self, theIndex: int, theNewNode: BRepMesh_Vertex) -> bool: ...

class BRepMesh_Deflection(Standard_Transient):
	@staticmethod
	def ComputeAbsoluteDeflection(theShape: TopoDS_Shape, theRelativeDeflection: float, theMaxShapeSize: float) -> float: ...
	@staticmethod
	def IsConsistent(theCurrent: float, theRequired: float, theAllowDecrease: bool, theRatio: Optional[float] = 0.1) -> bool: ...

class BRepMesh_DelabellaMeshAlgoFactory(IMeshTools_MeshAlgoFactory):
	def __init__(self) -> None: ...
	def GetAlgo(self, theSurfaceType: GeomAbs_SurfaceType, theParameters: IMeshTools_Parameters) -> IMeshTools_MeshAlgo: ...

class BRepMesh_Delaun:
	@overload
	def __init__(self, theOldMesh: BRepMesh_DataStructureOfDelaun, theCellsCountU: int, theCellsCountV: int, isFillCircles: bool) -> None: ...
	def Circles(self) -> BRepMesh_CircleTool: ...
	def Contains(self, theTriangleId: int, theVertex: BRepMesh_Vertex, theSqTolerance: float) -> Tuple[bool, int]: ...
	def GetEdge(self, theIndex: int) -> BRepMesh_Edge: ...
	def GetTriangle(self, theIndex: int) -> BRepMesh_Triangle: ...
	def GetVertex(self, theIndex: int) -> BRepMesh_Vertex: ...
	def InitCirclesTool(self, theCellsCountU: int, theCellsCountV: int) -> None: ...
	def RemoveAuxElements(self) -> None: ...
	def RemoveVertex(self, theVertex: BRepMesh_Vertex) -> None: ...
	def Result(self) -> BRepMesh_DataStructureOfDelaun: ...
	def UseEdge(self, theEdge: int) -> bool: ...

class BRepMesh_DiscretFactory:
	def DefaultName(self) -> TCollection_AsciiString: ...
	def Discret(self, theShape: TopoDS_Shape, theLinDeflection: float, theAngDeflection: float) -> BRepMesh_DiscretRoot: ...
	def ErrorStatus(self) -> BRepMesh_FactoryError: ...
	def FunctionName(self) -> TCollection_AsciiString: ...
	@staticmethod
	def Get() -> BRepMesh_DiscretFactory: ...
	def Names(self) -> TColStd_MapOfAsciiString: ...
	def SetDefault(self, theName: TCollection_AsciiString, theFuncName: Optional[TCollection_AsciiString] = "DISCRETALGO") -> bool: ...
	def SetDefaultName(self, theName: TCollection_AsciiString) -> bool: ...
	def SetFunctionName(self, theFuncName: TCollection_AsciiString) -> bool: ...

class BRepMesh_DiscretRoot(Standard_Transient):
	def IsDone(self) -> bool: ...
	def Perform(self, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def SetShape(self, theShape: TopoDS_Shape) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...

class BRepMesh_EdgeDiscret(IMeshTools_ModelAlgo):
	def __init__(self) -> None: ...

class BRepMesh_FaceChecker(Standard_Transient):
	def Perform(self) -> bool: ...

class BRepMesh_FaceDiscret(IMeshTools_ModelAlgo):
	def __init__(self, theAlgoFactory: IMeshTools_MeshAlgoFactory) -> None: ...

class BRepMesh_GeomTool:
	@overload
	def __init__(self, theCurve: BRepAdaptor_Curve, theFirstParam: float, theLastParam: float, theLinDeflection: float, theAngDeflection: float, theMinPointsNb: Optional[int] = 2, theMinSize: Optional[float] = precision_Confusion()) -> None: ...
	@overload
	def __init__(self, theSurface: BRepAdaptor_HSurface, theIsoType: GeomAbs_IsoType, theParamIso: float, theFirstParam: float, theLastParam: float, theLinDeflection: float, theAngDeflection: float, theMinPointsNb: Optional[int] = 2, theMinSize: Optional[float] = precision_Confusion()) -> None: ...
	def AddPoint(self, thePoint: gp_Pnt, theParam: float, theIsReplace: Optional[bool] = True) -> int: ...
	@staticmethod
	def CellsCount(theSurface: Adaptor3d_HSurface, theVerticesNb: int, theDeflection: float, theRangeSplitter: BRepMesh_DefaultRangeSplitter) -> False: ...
	def NbPoints(self) -> int: ...
	@staticmethod
	def SquareDeflectionOfSegment(theFirstPoint: gp_Pnt, theLastPoint: gp_Pnt, theMidPoint: gp_Pnt) -> float: ...
	@overload
	def Value(self, theIndex: int, theIsoParam: float, thePoint: gp_Pnt, theUV: gp_Pnt2d) -> Tuple[bool, float]: ...
	@overload
	def Value(self, theIndex: int, theSurface: BRepAdaptor_HSurface, thePoint: gp_Pnt, theUV: gp_Pnt2d) -> Tuple[bool, float]: ...

class BRepMesh_MeshAlgoFactory(IMeshTools_MeshAlgoFactory):
	def __init__(self) -> None: ...
	def GetAlgo(self, theSurfaceType: GeomAbs_SurfaceType, theParameters: IMeshTools_Parameters) -> IMeshTools_MeshAlgo: ...

class BRepMesh_MeshTool(Standard_Transient):
	@overload
	def __init__(self, theStructure: BRepMesh_DataStructureOfDelaun) -> None: ...
	def AddAndLegalizeTriangle(self, thePoint1: int, thePoint2: int, thePoint3: int) -> None: ...
	def AddLink(self, theFirstNode: int, theLastNode: int) -> Tuple[int, bool]: ...
	def CleanFrontierLinks(self) -> None: ...
	@overload
	def EraseFreeLinks(self) -> None: ...
	def EraseItemsConnectedTo(self, theNodeIndex: int) -> None: ...
	def GetStructure(self) -> BRepMesh_DataStructureOfDelaun: ...
	def Legalize(self, theLinkIndex: int) -> None: ...

class BRepMesh_ModelBuilder(IMeshTools_ModelBuilder):
	def __init__(self) -> None: ...

class BRepMesh_ModelHealer(IMeshTools_ModelAlgo):
	def __init__(self) -> None: ...

class BRepMesh_ModelPostProcessor(IMeshTools_ModelAlgo):
	def __init__(self) -> None: ...

class BRepMesh_ModelPreProcessor(IMeshTools_ModelAlgo):
	def __init__(self) -> None: ...

class BRepMesh_OrientedEdge:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theFirstNode: int, theLastNode: int) -> None: ...
	def FirstNode(self) -> int: ...
	def HashCode(self, theUpperBound: int) -> int: ...
	def IsEqual(self, theOther: BRepMesh_OrientedEdge) -> bool: ...
	def LastNode(self) -> int: ...

class BRepMesh_PairOfIndex:
	def __init__(self) -> None: ...
	def Append(self, theIndex: int) -> None: ...
	def Clear(self) -> None: ...
	def Extent(self) -> int: ...
	def FirstIndex(self) -> int: ...
	def Index(self, thePairPos: int) -> int: ...
	def IsEmpty(self) -> bool: ...
	def LastIndex(self) -> int: ...
	def Prepend(self, theIndex: int) -> None: ...
	def RemoveIndex(self, thePairPos: int) -> None: ...
	def SetIndex(self, thePairPos: int, theIndex: int) -> None: ...

class BRepMesh_SelectorOfDataStructureOfDelaun(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theMesh: BRepMesh_DataStructureOfDelaun) -> None: ...
	def AddNeighbours(self) -> None: ...
	def Elements(self) -> False: ...
	def FrontierLinks(self) -> False: ...
	def Initialize(self, theMesh: BRepMesh_DataStructureOfDelaun) -> None: ...
	def Links(self) -> False: ...
	def NeighboursByEdgeOf(self, theElement: BRepMesh_Triangle) -> None: ...
	@overload
	def NeighboursOf(self, theNode: BRepMesh_Vertex) -> None: ...
	@overload
	def NeighboursOf(self, theLink: BRepMesh_Edge) -> None: ...
	@overload
	def NeighboursOf(self, theElement: BRepMesh_Triangle) -> None: ...
	def NeighboursOfElement(self, theElementIndex: int) -> None: ...
	def NeighboursOfLink(self, theLinkIndex: int) -> None: ...
	def NeighboursOfNode(self, theNodeIndex: int) -> None: ...
	def Nodes(self) -> False: ...

class BRepMesh_ShapeTool(Standard_Transient):
	@staticmethod
	def AddInFace(theFace: TopoDS_Face, theTriangulation: Poly_Triangulation) -> None: ...
	@staticmethod
	def BoxMaxDimension(theBox: Bnd_Box) -> float: ...
	@staticmethod
	def MaxFaceTolerance(theFace: TopoDS_Face) -> float: ...
	@overload
	@staticmethod
	def NullifyEdge(theEdge: TopoDS_Edge, theTriangulation: Poly_Triangulation, theLocation: TopLoc_Location) -> None: ...
	@overload
	@staticmethod
	def NullifyEdge(theEdge: TopoDS_Edge, theLocation: TopLoc_Location) -> None: ...
	@staticmethod
	def NullifyFace(theFace: TopoDS_Face) -> None: ...
	@overload
	@staticmethod
	def Range(theEdge: TopoDS_Edge, theFace: TopoDS_Face, thePCurve: Geom2d_Curve, isConsiderOrientation: Optional[bool] = False) -> Tuple[bool, float, float]: ...
	@overload
	@staticmethod
	def Range(theEdge: TopoDS_Edge, theCurve: Geom_Curve, isConsiderOrientation: Optional[bool] = False) -> Tuple[bool, float, float]: ...
	@staticmethod
	def UVPoints(theEdge: TopoDS_Edge, theFace: TopoDS_Face, theFirstPoint2d: gp_Pnt2d, theLastPoint2d: gp_Pnt2d, isConsiderOrientation: Optional[bool] = False) -> bool: ...
	@overload
	@staticmethod
	def UpdateEdge(theEdge: TopoDS_Edge, thePolygon: Poly_PolygonOnTriangulation, theTriangulation: Poly_Triangulation, theLocation: TopLoc_Location) -> None: ...
	@overload
	@staticmethod
	def UpdateEdge(theEdge: TopoDS_Edge, thePolygon: Poly_Polygon3D) -> None: ...
	@overload
	@staticmethod
	def UpdateEdge(theEdge: TopoDS_Edge, thePolygon1: Poly_PolygonOnTriangulation, thePolygon2: Poly_PolygonOnTriangulation, theTriangulation: Poly_Triangulation, theLocation: TopLoc_Location) -> None: ...
	@staticmethod
	def UseLocation(thePnt: gp_Pnt, theLoc: TopLoc_Location) -> gp_Pnt: ...

class BRepMesh_ShapeVisitor(IMeshTools_ShapeVisitor):
	def __init__(self, theModel: IMeshData_Model) -> None: ...
	@overload
	def Visit(self, theFace: TopoDS_Face) -> None: ...
	@overload
	def Visit(self, theEdge: TopoDS_Edge) -> None: ...

class BRepMesh_Triangle:
	@overload
	def __init__(self) -> None: ...
	def HashCode(self, theUpperBound: int) -> int: ...
	def IsEqual(self, theOther: BRepMesh_Triangle) -> bool: ...
	def Movability(self) -> BRepMesh_DegreeOfFreedom: ...
	def SetMovability(self, theMovability: BRepMesh_DegreeOfFreedom) -> None: ...

class BRepMesh_Vertex:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theUV: gp_XY, theLocation3d: int, theMovability: BRepMesh_DegreeOfFreedom) -> None: ...
	@overload
	def __init__(self, theU: float, theV: float, theMovability: BRepMesh_DegreeOfFreedom) -> None: ...
	def ChangeCoord(self) -> gp_XY: ...
	def Coord(self) -> gp_XY: ...
	def HashCode(self, theUpperBound: int) -> int: ...
	def Initialize(self, theUV: gp_XY, theLocation3d: int, theMovability: BRepMesh_DegreeOfFreedom) -> None: ...
	def IsEqual(self, theOther: BRepMesh_Vertex) -> bool: ...
	def Location3d(self) -> int: ...
	def Movability(self) -> BRepMesh_DegreeOfFreedom: ...
	def SetMovability(self, theMovability: BRepMesh_DegreeOfFreedom) -> None: ...

class BRepMesh_VertexInspector(NCollection_CellFilter_InspectorXY):
	@overload
	def __init__(self, theAllocator: NCollection_IncAllocator) -> None: ...
	def Add(self, theVertex: BRepMesh_Vertex) -> int: ...
	def Clear(self) -> None: ...
	def Delete(self, theIndex: int) -> None: ...
	def GetCoincidentPoint(self) -> int: ...
	def GetListOfDelPoints(self) -> False: ...
	def GetVertex(self, theIndex: int) -> BRepMesh_Vertex: ...
	def Inspect(self, theTargetIndex: int) -> NCollection_CellFilter_Action: ...
	@staticmethod
	def IsEqual(theIndex: int, theTargetIndex: int) -> bool: ...
	def NbVertices(self) -> int: ...
	def SetPoint(self, thePoint: gp_XY) -> None: ...
	@overload
	def SetTolerance(self, theTolerance: float) -> None: ...
	@overload
	def SetTolerance(self, theToleranceX: float, theToleranceY: float) -> None: ...

class BRepMesh_VertexTool(Standard_Transient):
	@overload
	def __init__(self, theAllocator: NCollection_IncAllocator) -> None: ...
	def Add(self, theVertex: BRepMesh_Vertex, isForceAdd: bool) -> int: ...
	def DeleteVertex(self, theIndex: int) -> None: ...
	def Extent(self) -> int: ...
	def FindIndex(self, theVertex: BRepMesh_Vertex) -> int: ...
	def FindKey(self, theIndex: int) -> BRepMesh_Vertex: ...
	def GetListOfDelNodes(self) -> False: ...
	def GetTolerance(self) -> Tuple[float, float]: ...
	def IsEmpty(self) -> bool: ...
	def RemoveLast(self) -> None: ...
	@overload
	def SetCellSize(self, theSize: float) -> None: ...
	@overload
	def SetCellSize(self, theSizeX: float, theSizeY: float) -> None: ...
	@overload
	def SetTolerance(self, theTolerance: float) -> None: ...
	@overload
	def SetTolerance(self, theToleranceX: float, theToleranceY: float) -> None: ...
	def Substitute(self, theIndex: int, theVertex: BRepMesh_Vertex) -> None: ...

class BRepMesh_DelabellaBaseMeshAlgo(BRepMesh_CustomBaseMeshAlgo):
	def __init__(self) -> None: ...

class BRepMesh_Edge(BRepMesh_OrientedEdge):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theFirstNode: int, theLastNode: int, theMovability: BRepMesh_DegreeOfFreedom) -> None: ...
	def IsEqual(self, theOther: BRepMesh_Edge) -> bool: ...
	def IsSameOrientation(self, theOther: BRepMesh_Edge) -> bool: ...
	def Movability(self) -> BRepMesh_DegreeOfFreedom: ...
	def SetMovability(self, theMovability: BRepMesh_DegreeOfFreedom) -> None: ...

class BRepMesh_IncrementalMesh(BRepMesh_DiscretRoot):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theShape: TopoDS_Shape, theLinDeflection: float, isRelative: Optional[bool] = False, theAngDeflection: Optional[float] = 0.5, isInParallel: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, theShape: TopoDS_Shape, theParameters: IMeshTools_Parameters, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def ChangeParameters(self) -> IMeshTools_Parameters: ...
	@staticmethod
	def Discret(theShape: TopoDS_Shape, theLinDeflection: float, theAngDeflection: float, theAlgo: BRepMesh_DiscretRoot) -> int: ...
	def GetStatusFlags(self) -> int: ...
	def IsModified(self) -> bool: ...
	@staticmethod
	def IsParallelDefault() -> bool: ...
	def Parameters(self) -> IMeshTools_Parameters: ...
	@overload
	def Perform(self, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	@overload
	def Perform(self, theContext: IMeshTools_Context, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	@staticmethod
	def SetParallelDefault(isInParallel: bool) -> None: ...

class BRepMesh_DelaunayBaseMeshAlgo(BRepMesh_ConstrainedBaseMeshAlgo):
	def __init__(self) -> None: ...

#classnotwrapped
class BRepMesh_WireInterferenceChecker: ...

#classnotwrapped
class BRepMesh_EdgeTessellator: ...

#classnotwrapped
class BRepMesh_EdgeTessellationExtractor: ...

#classnotwrapped
class BRepMesh_EdgeParameterProvider: ...

#classnotwrapped
class BRepMesh_FastDiscret: ...

#classnotwrapped
class BRepMesh_CustomDelaunayBaseMeshAlgo: ...

#classnotwrapped
class BRepMesh_NodeInsertionMeshAlgo: ...

#classnotwrapped
class BRepMesh_ConstrainedBaseMeshAlgo: ...

#classnotwrapped
class BRepMesh_CustomBaseMeshAlgo: ...

#classnotwrapped
class BRepMesh_DelaunayDeflectionControlMeshAlgo: ...

#classnotwrapped
class BRepMesh_DelaunayNodeInsertionMeshAlgo: ...

# harray1 classes
# harray2 classes
# hsequence classes

BRepMesh_CircleInspector_IsEqual = BRepMesh_CircleInspector.IsEqual
BRepMesh_CircleTool_MakeCircle = BRepMesh_CircleTool.MakeCircle
BRepMesh_Deflection_ComputeAbsoluteDeflection = BRepMesh_Deflection.ComputeAbsoluteDeflection
BRepMesh_Deflection_ComputeDeflection = BRepMesh_Deflection.ComputeDeflection
BRepMesh_Deflection_ComputeDeflection = BRepMesh_Deflection.ComputeDeflection
BRepMesh_Deflection_ComputeDeflection = BRepMesh_Deflection.ComputeDeflection
BRepMesh_Deflection_IsConsistent = BRepMesh_Deflection.IsConsistent
BRepMesh_DiscretFactory_Get = BRepMesh_DiscretFactory.Get
BRepMesh_EdgeDiscret_CreateEdgeTessellationExtractor = BRepMesh_EdgeDiscret.CreateEdgeTessellationExtractor
BRepMesh_EdgeDiscret_CreateEdgeTessellator = BRepMesh_EdgeDiscret.CreateEdgeTessellator
BRepMesh_EdgeDiscret_CreateEdgeTessellator = BRepMesh_EdgeDiscret.CreateEdgeTessellator
BRepMesh_EdgeDiscret_Tessellate2d = BRepMesh_EdgeDiscret.Tessellate2d
BRepMesh_EdgeDiscret_Tessellate3d = BRepMesh_EdgeDiscret.Tessellate3d
BRepMesh_GeomTool_CellsCount = BRepMesh_GeomTool.CellsCount
BRepMesh_GeomTool_SquareDeflectionOfSegment = BRepMesh_GeomTool.SquareDeflectionOfSegment
BRepMesh_ShapeTool_AddInFace = BRepMesh_ShapeTool.AddInFace
BRepMesh_ShapeTool_BoxMaxDimension = BRepMesh_ShapeTool.BoxMaxDimension
BRepMesh_ShapeTool_CheckAndUpdateFlags = BRepMesh_ShapeTool.CheckAndUpdateFlags
BRepMesh_ShapeTool_MaxFaceTolerance = BRepMesh_ShapeTool.MaxFaceTolerance
BRepMesh_ShapeTool_NullifyEdge = BRepMesh_ShapeTool.NullifyEdge
BRepMesh_ShapeTool_NullifyEdge = BRepMesh_ShapeTool.NullifyEdge
BRepMesh_ShapeTool_NullifyFace = BRepMesh_ShapeTool.NullifyFace
BRepMesh_ShapeTool_Range = BRepMesh_ShapeTool.Range
BRepMesh_ShapeTool_Range = BRepMesh_ShapeTool.Range
BRepMesh_ShapeTool_UVPoints = BRepMesh_ShapeTool.UVPoints
BRepMesh_ShapeTool_UpdateEdge = BRepMesh_ShapeTool.UpdateEdge
BRepMesh_ShapeTool_UpdateEdge = BRepMesh_ShapeTool.UpdateEdge
BRepMesh_ShapeTool_UpdateEdge = BRepMesh_ShapeTool.UpdateEdge
BRepMesh_ShapeTool_UseLocation = BRepMesh_ShapeTool.UseLocation
BRepMesh_VertexInspector_IsEqual = BRepMesh_VertexInspector.IsEqual
BRepMesh_IncrementalMesh_Discret = BRepMesh_IncrementalMesh.Discret
BRepMesh_IncrementalMesh_IsParallelDefault = BRepMesh_IncrementalMesh.IsParallelDefault
BRepMesh_IncrementalMesh_SetParallelDefault = BRepMesh_IncrementalMesh.SetParallelDefault



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom2d import *
from OCC.Core.gp import *
from OCC.Core.LProp import *
from OCC.Core.math import *


class Geom2dLProp_CLProps2d:
	@overload
	def __init__(self, C: Geom2d_Curve, N: int, Resolution: float) -> None: ...
	@overload
	def __init__(self, C: Geom2d_Curve, U: float, N: int, Resolution: float) -> None: ...
	@overload
	def __init__(self, N: int, Resolution: float) -> None: ...
	def CentreOfCurvature(self, P: gp_Pnt2d) -> None: ...
	def Curvature(self) -> float: ...
	def D1(self) -> gp_Vec2d: ...
	def D2(self) -> gp_Vec2d: ...
	def D3(self) -> gp_Vec2d: ...
	def IsTangentDefined(self) -> bool: ...
	def Normal(self, N: gp_Dir2d) -> None: ...
	def SetCurve(self, C: Geom2d_Curve) -> None: ...
	def SetParameter(self, U: float) -> None: ...
	def Tangent(self, D: gp_Dir2d) -> None: ...
	def Value(self) -> gp_Pnt2d: ...

class Geom2dLProp_CurAndInf2d(LProp_CurAndInf):
	def __init__(self) -> None: ...
	def IsDone(self) -> bool: ...
	def Perform(self, C: Geom2d_Curve) -> None: ...
	def PerformCurExt(self, C: Geom2d_Curve) -> None: ...
	def PerformInf(self, C: Geom2d_Curve) -> None: ...

class Geom2dLProp_Curve2dTool:
	@staticmethod
	def Continuity(C: Geom2d_Curve) -> int: ...
	@staticmethod
	def D1(C: Geom2d_Curve, U: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	@staticmethod
	def D2(C: Geom2d_Curve, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	@staticmethod
	def D3(C: Geom2d_Curve, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	@staticmethod
	def FirstParameter(C: Geom2d_Curve) -> float: ...
	@staticmethod
	def LastParameter(C: Geom2d_Curve) -> float: ...
	@staticmethod
	def Value(C: Geom2d_Curve, U: float, P: gp_Pnt2d) -> None: ...

class Geom2dLProp_FuncCurExt(math_FunctionWithDerivative):
	def __init__(self, C: Geom2d_Curve, Tol: float) -> None: ...
	def Derivative(self, X: float) -> Tuple[bool, float]: ...
	def IsMinKC(self, Param: float) -> bool: ...
	def Value(self, X: float) -> Tuple[bool, float]: ...
	def Values(self, X: float) -> Tuple[bool, float, float]: ...

class Geom2dLProp_FuncCurNul(math_FunctionWithDerivative):
	def __init__(self, C: Geom2d_Curve) -> None: ...
	def Derivative(self, X: float) -> Tuple[bool, float]: ...
	def Value(self, X: float) -> Tuple[bool, float]: ...
	def Values(self, X: float) -> Tuple[bool, float, float]: ...

class Geom2dLProp_NumericCurInf2d:
	def __init__(self) -> None: ...
	def IsDone(self) -> bool: ...
	@overload
	def PerformCurExt(self, C: Geom2d_Curve, Result: LProp_CurAndInf) -> None: ...
	@overload
	def PerformCurExt(self, C: Geom2d_Curve, UMin: float, UMax: float, Result: LProp_CurAndInf) -> None: ...
	@overload
	def PerformInf(self, C: Geom2d_Curve, Result: LProp_CurAndInf) -> None: ...
	@overload
	def PerformInf(self, C: Geom2d_Curve, UMin: float, UMax: float, Result: LProp_CurAndInf) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

Geom2dLProp_Curve2dTool_Continuity = Geom2dLProp_Curve2dTool.Continuity
Geom2dLProp_Curve2dTool_D1 = Geom2dLProp_Curve2dTool.D1
Geom2dLProp_Curve2dTool_D2 = Geom2dLProp_Curve2dTool.D2
Geom2dLProp_Curve2dTool_D3 = Geom2dLProp_Curve2dTool.D3
Geom2dLProp_Curve2dTool_FirstParameter = Geom2dLProp_Curve2dTool.FirstParameter
Geom2dLProp_Curve2dTool_LastParameter = Geom2dLProp_Curve2dTool.LastParameter
Geom2dLProp_Curve2dTool_Value = Geom2dLProp_Curve2dTool.Value



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.StepGeom import *
from OCC.Core.TCollection import *
from OCC.Core.StepRepr import *
from OCC.Core.StepData import *
from OCC.Core.StepBasic import *


class StepShape_Array1OfConnectedEdgeSet:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepShape_Array1OfConnectedFaceSet:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepShape_Array1OfEdge:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepShape_Array1OfFace:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepShape_Array1OfFaceBound:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepShape_Array1OfGeometricSetSelect:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepShape_GeometricSetSelect: ...
    def __setitem__(self, index: int, value: StepShape_GeometricSetSelect) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepShape_GeometricSetSelect]: ...
    def next(self) -> StepShape_GeometricSetSelect: ...
    __next__ = next
    def Init(self, theValue: StepShape_GeometricSetSelect) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepShape_GeometricSetSelect: ...
    def Last(self) -> StepShape_GeometricSetSelect: ...
    def Value(self, theIndex: int) -> StepShape_GeometricSetSelect: ...
    def SetValue(self, theIndex: int, theValue: StepShape_GeometricSetSelect) -> None: ...

class StepShape_Array1OfOrientedClosedShell:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepShape_Array1OfOrientedEdge:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepShape_Array1OfShapeDimensionRepresentationItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepShape_ShapeDimensionRepresentationItem: ...
    def __setitem__(self, index: int, value: StepShape_ShapeDimensionRepresentationItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepShape_ShapeDimensionRepresentationItem]: ...
    def next(self) -> StepShape_ShapeDimensionRepresentationItem: ...
    __next__ = next
    def Init(self, theValue: StepShape_ShapeDimensionRepresentationItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepShape_ShapeDimensionRepresentationItem: ...
    def Last(self) -> StepShape_ShapeDimensionRepresentationItem: ...
    def Value(self, theIndex: int) -> StepShape_ShapeDimensionRepresentationItem: ...
    def SetValue(self, theIndex: int, theValue: StepShape_ShapeDimensionRepresentationItem) -> None: ...

class StepShape_Array1OfShell:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepShape_Shell: ...
    def __setitem__(self, index: int, value: StepShape_Shell) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepShape_Shell]: ...
    def next(self) -> StepShape_Shell: ...
    __next__ = next
    def Init(self, theValue: StepShape_Shell) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepShape_Shell: ...
    def Last(self) -> StepShape_Shell: ...
    def Value(self, theIndex: int) -> StepShape_Shell: ...
    def SetValue(self, theIndex: int, theValue: StepShape_Shell) -> None: ...

class StepShape_Array1OfValueQualifier:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepShape_ValueQualifier: ...
    def __setitem__(self, index: int, value: StepShape_ValueQualifier) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepShape_ValueQualifier]: ...
    def next(self) -> StepShape_ValueQualifier: ...
    __next__ = next
    def Init(self, theValue: StepShape_ValueQualifier) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepShape_ValueQualifier: ...
    def Last(self) -> StepShape_ValueQualifier: ...
    def Value(self, theIndex: int) -> StepShape_ValueQualifier: ...
    def SetValue(self, theIndex: int, theValue: StepShape_ValueQualifier) -> None: ...

class StepShape_AngleRelator(IntEnum):
	StepShape_Equal: int = ...
	StepShape_Large: int = ...
	StepShape_Small: int = ...
StepShape_Equal = StepShape_AngleRelator.StepShape_Equal
StepShape_Large = StepShape_AngleRelator.StepShape_Large
StepShape_Small = StepShape_AngleRelator.StepShape_Small

class StepShape_BooleanOperator(IntEnum):
	StepShape_boDifference: int = ...
	StepShape_boIntersection: int = ...
	StepShape_boUnion: int = ...
StepShape_boDifference = StepShape_BooleanOperator.StepShape_boDifference
StepShape_boIntersection = StepShape_BooleanOperator.StepShape_boIntersection
StepShape_boUnion = StepShape_BooleanOperator.StepShape_boUnion

class StepShape_Block(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis2Placement3d, aX: float, aY: float, aZ: float) -> None: ...
	def Position(self) -> StepGeom_Axis2Placement3d: ...
	def SetPosition(self, aPosition: StepGeom_Axis2Placement3d) -> None: ...
	def SetX(self, aX: float) -> None: ...
	def SetY(self, aY: float) -> None: ...
	def SetZ(self, aZ: float) -> None: ...
	def X(self) -> float: ...
	def Y(self) -> float: ...
	def Z(self) -> float: ...

class StepShape_BooleanOperand:
	def __init__(self) -> None: ...
	def BooleanResult(self) -> StepShape_BooleanResult: ...
	def CsgPrimitive(self) -> StepShape_CsgPrimitive: ...
	def HalfSpaceSolid(self) -> StepShape_HalfSpaceSolid: ...
	def SetBooleanResult(self, aBooleanResult: StepShape_BooleanResult) -> None: ...
	def SetCsgPrimitive(self, aCsgPrimitive: StepShape_CsgPrimitive) -> None: ...
	def SetHalfSpaceSolid(self, aHalfSpaceSolid: StepShape_HalfSpaceSolid) -> None: ...
	def SetSolidModel(self, aSolidModel: StepShape_SolidModel) -> None: ...
	def SetTypeOfContent(self, aTypeOfContent: int) -> None: ...
	def SolidModel(self) -> StepShape_SolidModel: ...
	def TypeOfContent(self) -> int: ...

class StepShape_BooleanResult(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def FirstOperand(self) -> StepShape_BooleanOperand: ...
	def Init(self, aName: TCollection_HAsciiString, aOperator: StepShape_BooleanOperator, aFirstOperand: StepShape_BooleanOperand, aSecondOperand: StepShape_BooleanOperand) -> None: ...
	def Operator(self) -> StepShape_BooleanOperator: ...
	def SecondOperand(self) -> StepShape_BooleanOperand: ...
	def SetFirstOperand(self, aFirstOperand: StepShape_BooleanOperand) -> None: ...
	def SetOperator(self, aOperator: StepShape_BooleanOperator) -> None: ...
	def SetSecondOperand(self, aSecondOperand: StepShape_BooleanOperand) -> None: ...

class StepShape_BoxDomain(Standard_Transient):
	def __init__(self) -> None: ...
	def Corner(self) -> StepGeom_CartesianPoint: ...
	def Init(self, aCorner: StepGeom_CartesianPoint, aXlength: float, aYlength: float, aZlength: float) -> None: ...
	def SetCorner(self, aCorner: StepGeom_CartesianPoint) -> None: ...
	def SetXlength(self, aXlength: float) -> None: ...
	def SetYlength(self, aYlength: float) -> None: ...
	def SetZlength(self, aZlength: float) -> None: ...
	def Xlength(self) -> float: ...
	def Ylength(self) -> float: ...
	def Zlength(self) -> float: ...

class StepShape_ConnectedFaceShapeRepresentation(StepRepr_Representation):
	def __init__(self) -> None: ...

class StepShape_ContextDependentShapeRepresentation(Standard_Transient):
	def __init__(self) -> None: ...
	def Init(self, aRepRel: StepRepr_ShapeRepresentationRelationship, aProRel: StepRepr_ProductDefinitionShape) -> None: ...
	def RepresentationRelation(self) -> StepRepr_ShapeRepresentationRelationship: ...
	def RepresentedProductRelation(self) -> StepRepr_ProductDefinitionShape: ...
	def SetRepresentationRelation(self, aRepRel: StepRepr_ShapeRepresentationRelationship) -> None: ...
	def SetRepresentedProductRelation(self, aProRel: StepRepr_ProductDefinitionShape) -> None: ...

class StepShape_CsgPrimitive(StepData_SelectType):
	def __init__(self) -> None: ...
	def Block(self) -> StepShape_Block: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def RightAngularWedge(self) -> StepShape_RightAngularWedge: ...
	def RightCircularCone(self) -> StepShape_RightCircularCone: ...
	def RightCircularCylinder(self) -> StepShape_RightCircularCylinder: ...
	def Sphere(self) -> StepShape_Sphere: ...
	def Torus(self) -> StepShape_Torus: ...

class StepShape_CsgSelect:
	def __init__(self) -> None: ...
	def BooleanResult(self) -> StepShape_BooleanResult: ...
	def CsgPrimitive(self) -> StepShape_CsgPrimitive: ...
	def SetBooleanResult(self, aBooleanResult: StepShape_BooleanResult) -> None: ...
	def SetCsgPrimitive(self, aCsgPrimitive: StepShape_CsgPrimitive) -> None: ...
	def SetTypeOfContent(self, aTypeOfContent: int) -> None: ...
	def TypeOfContent(self) -> int: ...

class StepShape_DefinitionalRepresentationAndShapeRepresentation(StepRepr_DefinitionalRepresentation):
	def __init__(self) -> None: ...

class StepShape_DimensionalCharacteristic(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def DimensionalLocation(self) -> StepShape_DimensionalLocation: ...
	def DimensionalSize(self) -> StepShape_DimensionalSize: ...

class StepShape_DimensionalCharacteristicRepresentation(Standard_Transient):
	def __init__(self) -> None: ...
	def Dimension(self) -> StepShape_DimensionalCharacteristic: ...
	def Init(self, aDimension: StepShape_DimensionalCharacteristic, aRepresentation: StepShape_ShapeDimensionRepresentation) -> None: ...
	def Representation(self) -> StepShape_ShapeDimensionRepresentation: ...
	def SetDimension(self, Dimension: StepShape_DimensionalCharacteristic) -> None: ...
	def SetRepresentation(self, Representation: StepShape_ShapeDimensionRepresentation) -> None: ...

class StepShape_DimensionalLocation(StepRepr_ShapeAspectRelationship):
	def __init__(self) -> None: ...

class StepShape_DimensionalSize(Standard_Transient):
	def __init__(self) -> None: ...
	def AppliesTo(self) -> StepRepr_ShapeAspect: ...
	def Init(self, aAppliesTo: StepRepr_ShapeAspect, aName: TCollection_HAsciiString) -> None: ...
	def Name(self) -> TCollection_HAsciiString: ...
	def SetAppliesTo(self, AppliesTo: StepRepr_ShapeAspect) -> None: ...
	def SetName(self, Name: TCollection_HAsciiString) -> None: ...

class StepShape_EdgeBasedWireframeModel(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def EbwmBoundary(self) -> StepShape_HArray1OfConnectedEdgeSet: ...
	def Init(self, aRepresentationItem_Name: TCollection_HAsciiString, aEbwmBoundary: StepShape_HArray1OfConnectedEdgeSet) -> None: ...
	def SetEbwmBoundary(self, EbwmBoundary: StepShape_HArray1OfConnectedEdgeSet) -> None: ...

class StepShape_FaceBasedSurfaceModel(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def FbsmFaces(self) -> StepShape_HArray1OfConnectedFaceSet: ...
	def Init(self, aRepresentationItem_Name: TCollection_HAsciiString, aFbsmFaces: StepShape_HArray1OfConnectedFaceSet) -> None: ...
	def SetFbsmFaces(self, FbsmFaces: StepShape_HArray1OfConnectedFaceSet) -> None: ...

class StepShape_GeometricSet(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def Elements(self) -> StepShape_HArray1OfGeometricSetSelect: ...
	def ElementsValue(self, num: int) -> StepShape_GeometricSetSelect: ...
	def Init(self, aName: TCollection_HAsciiString, aElements: StepShape_HArray1OfGeometricSetSelect) -> None: ...
	def NbElements(self) -> int: ...
	def SetElements(self, aElements: StepShape_HArray1OfGeometricSetSelect) -> None: ...

class StepShape_GeometricSetSelect(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def Curve(self) -> StepGeom_Curve: ...
	def Point(self) -> StepGeom_Point: ...
	def Surface(self) -> StepGeom_Surface: ...

class StepShape_HalfSpaceSolid(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def AgreementFlag(self) -> bool: ...
	def BaseSurface(self) -> StepGeom_Surface: ...
	def Init(self, aName: TCollection_HAsciiString, aBaseSurface: StepGeom_Surface, aAgreementFlag: bool) -> None: ...
	def SetAgreementFlag(self, aAgreementFlag: bool) -> None: ...
	def SetBaseSurface(self, aBaseSurface: StepGeom_Surface) -> None: ...

class StepShape_LimitsAndFits(Standard_Transient):
	def __init__(self) -> None: ...
	def FormVariance(self) -> TCollection_HAsciiString: ...
	def Grade(self) -> TCollection_HAsciiString: ...
	def Init(self, form_variance: TCollection_HAsciiString, zone_variance: TCollection_HAsciiString, grade: TCollection_HAsciiString, source: TCollection_HAsciiString) -> None: ...
	def SetFormVariance(self, form_variance: TCollection_HAsciiString) -> None: ...
	def SetGrade(self, grade: TCollection_HAsciiString) -> None: ...
	def SetSource(self, source: TCollection_HAsciiString) -> None: ...
	def SetZoneVariance(self, zone_variance: TCollection_HAsciiString) -> None: ...
	def Source(self) -> TCollection_HAsciiString: ...
	def ZoneVariance(self) -> TCollection_HAsciiString: ...

class StepShape_MeasureQualification(Standard_Transient):
	def __init__(self) -> None: ...
	def Description(self) -> TCollection_HAsciiString: ...
	def Init(self, name: TCollection_HAsciiString, description: TCollection_HAsciiString, qualified_measure: StepBasic_MeasureWithUnit, qualifiers: StepShape_HArray1OfValueQualifier) -> None: ...
	def Name(self) -> TCollection_HAsciiString: ...
	def NbQualifiers(self) -> int: ...
	def QualifiedMeasure(self) -> StepBasic_MeasureWithUnit: ...
	def Qualifiers(self) -> StepShape_HArray1OfValueQualifier: ...
	def QualifiersValue(self, num: int) -> StepShape_ValueQualifier: ...
	def SetDescription(self, description: TCollection_HAsciiString) -> None: ...
	def SetName(self, name: TCollection_HAsciiString) -> None: ...
	def SetQualifiedMeasure(self, qualified_measure: StepBasic_MeasureWithUnit) -> None: ...
	def SetQualifiers(self, qualifiers: StepShape_HArray1OfValueQualifier) -> None: ...
	def SetQualifiersValue(self, num: int, aqualifier: StepShape_ValueQualifier) -> None: ...

class StepShape_MeasureRepresentationItemAndQualifiedRepresentationItem(StepRepr_RepresentationItem):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aValueComponent: StepBasic_MeasureValueMember, aUnitComponent: StepBasic_Unit, qualifiers: StepShape_HArray1OfValueQualifier) -> None: ...
	def Measure(self) -> StepBasic_MeasureWithUnit: ...
	def NbQualifiers(self) -> int: ...
	def Qualifiers(self) -> StepShape_HArray1OfValueQualifier: ...
	def QualifiersValue(self, num: int) -> StepShape_ValueQualifier: ...
	def SetMeasure(self, Measure: StepBasic_MeasureWithUnit) -> None: ...
	def SetQualifiers(self, qualifiers: StepShape_HArray1OfValueQualifier) -> None: ...
	def SetQualifiersValue(self, num: int, aqualifier: StepShape_ValueQualifier) -> None: ...

class StepShape_PlusMinusTolerance(Standard_Transient):
	def __init__(self) -> None: ...
	def Init(self, range: StepShape_ToleranceMethodDefinition, toleranced_dimension: StepShape_DimensionalCharacteristic) -> None: ...
	def Range(self) -> StepShape_ToleranceMethodDefinition: ...
	def SetRange(self, range: StepShape_ToleranceMethodDefinition) -> None: ...
	def SetTolerancedDimension(self, toleranced_dimension: StepShape_DimensionalCharacteristic) -> None: ...
	def TolerancedDimension(self) -> StepShape_DimensionalCharacteristic: ...

class StepShape_PrecisionQualifier(Standard_Transient):
	def __init__(self) -> None: ...
	def Init(self, precision_value: int) -> None: ...
	def PrecisionValue(self) -> int: ...
	def SetPrecisionValue(self, precision_value: int) -> None: ...

class StepShape_QualifiedRepresentationItem(StepRepr_RepresentationItem):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, qualifiers: StepShape_HArray1OfValueQualifier) -> None: ...
	def NbQualifiers(self) -> int: ...
	def Qualifiers(self) -> StepShape_HArray1OfValueQualifier: ...
	def QualifiersValue(self, num: int) -> StepShape_ValueQualifier: ...
	def SetQualifiers(self, qualifiers: StepShape_HArray1OfValueQualifier) -> None: ...
	def SetQualifiersValue(self, num: int, aqualifier: StepShape_ValueQualifier) -> None: ...

class StepShape_ReversibleTopologyItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ClosedShell(self) -> StepShape_ClosedShell: ...
	def Edge(self) -> StepShape_Edge: ...
	def Face(self) -> StepShape_Face: ...
	def FaceBound(self) -> StepShape_FaceBound: ...
	def OpenShell(self) -> StepShape_OpenShell: ...
	def Path(self) -> StepShape_Path: ...

class StepShape_RightAngularWedge(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis2Placement3d, aX: float, aY: float, aZ: float, aLtx: float) -> None: ...
	def Ltx(self) -> float: ...
	def Position(self) -> StepGeom_Axis2Placement3d: ...
	def SetLtx(self, aLtx: float) -> None: ...
	def SetPosition(self, aPosition: StepGeom_Axis2Placement3d) -> None: ...
	def SetX(self, aX: float) -> None: ...
	def SetY(self, aY: float) -> None: ...
	def SetZ(self, aZ: float) -> None: ...
	def X(self) -> float: ...
	def Y(self) -> float: ...
	def Z(self) -> float: ...

class StepShape_RightCircularCone(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def Height(self) -> float: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis1Placement, aHeight: float, aRadius: float, aSemiAngle: float) -> None: ...
	def Position(self) -> StepGeom_Axis1Placement: ...
	def Radius(self) -> float: ...
	def SemiAngle(self) -> float: ...
	def SetHeight(self, aHeight: float) -> None: ...
	def SetPosition(self, aPosition: StepGeom_Axis1Placement) -> None: ...
	def SetRadius(self, aRadius: float) -> None: ...
	def SetSemiAngle(self, aSemiAngle: float) -> None: ...

class StepShape_RightCircularCylinder(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def Height(self) -> float: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis1Placement, aHeight: float, aRadius: float) -> None: ...
	def Position(self) -> StepGeom_Axis1Placement: ...
	def Radius(self) -> float: ...
	def SetHeight(self, aHeight: float) -> None: ...
	def SetPosition(self, aPosition: StepGeom_Axis1Placement) -> None: ...
	def SetRadius(self, aRadius: float) -> None: ...

class StepShape_ShapeDefinitionRepresentation(StepRepr_PropertyDefinitionRepresentation):
	def __init__(self) -> None: ...

class StepShape_ShapeDimensionRepresentationItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def CompoundRepresentationItem(self) -> StepRepr_CompoundRepresentationItem: ...
	def DescriptiveRepresentationItem(self) -> StepRepr_DescriptiveRepresentationItem: ...
	def MeasureRepresentationItem(self) -> StepRepr_MeasureRepresentationItem: ...
	def Placement(self) -> StepGeom_Placement: ...

class StepShape_ShapeRepresentation(StepRepr_Representation):
	def __init__(self) -> None: ...

class StepShape_Shell(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ClosedShell(self) -> StepShape_ClosedShell: ...
	def OpenShell(self) -> StepShape_OpenShell: ...

class StepShape_ShellBasedSurfaceModel(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aSbsmBoundary: StepShape_HArray1OfShell) -> None: ...
	def NbSbsmBoundary(self) -> int: ...
	def SbsmBoundary(self) -> StepShape_HArray1OfShell: ...
	def SbsmBoundaryValue(self, num: int) -> StepShape_Shell: ...
	def SetSbsmBoundary(self, aSbsmBoundary: StepShape_HArray1OfShell) -> None: ...

class StepShape_SolidModel(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...

class StepShape_Sphere(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def Centre(self) -> StepGeom_Point: ...
	def Init(self, aName: TCollection_HAsciiString, aRadius: float, aCentre: StepGeom_Point) -> None: ...
	def Radius(self) -> float: ...
	def SetCentre(self, aCentre: StepGeom_Point) -> None: ...
	def SetRadius(self, aRadius: float) -> None: ...

class StepShape_SurfaceModel(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ShellBasedSurfaceModel(self) -> StepShape_ShellBasedSurfaceModel: ...

class StepShape_ToleranceMethodDefinition(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def LimitsAndFits(self) -> StepShape_LimitsAndFits: ...
	def ToleranceValue(self) -> StepShape_ToleranceValue: ...

class StepShape_ToleranceValue(Standard_Transient):
	def __init__(self) -> None: ...
	def Init(self, lower_bound: Standard_Transient, upper_bound: Standard_Transient) -> None: ...
	def LowerBound(self) -> Standard_Transient: ...
	def SetLowerBound(self, lower_bound: Standard_Transient) -> None: ...
	def SetUpperBound(self, upper_bound: Standard_Transient) -> None: ...
	def UpperBound(self) -> Standard_Transient: ...

class StepShape_TopologicalRepresentationItem(StepRepr_RepresentationItem):
	def __init__(self) -> None: ...

class StepShape_Torus(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis1Placement, aMajorRadius: float, aMinorRadius: float) -> None: ...
	def MajorRadius(self) -> float: ...
	def MinorRadius(self) -> float: ...
	def Position(self) -> StepGeom_Axis1Placement: ...
	def SetMajorRadius(self, aMajorRadius: float) -> None: ...
	def SetMinorRadius(self, aMinorRadius: float) -> None: ...
	def SetPosition(self, aPosition: StepGeom_Axis1Placement) -> None: ...

class StepShape_TypeQualifier(Standard_Transient):
	def __init__(self) -> None: ...
	def Init(self, name: TCollection_HAsciiString) -> None: ...
	def Name(self) -> TCollection_HAsciiString: ...
	def SetName(self, name: TCollection_HAsciiString) -> None: ...

class StepShape_ValueFormatTypeQualifier(Standard_Transient):
	def __init__(self) -> None: ...
	def FormatType(self) -> TCollection_HAsciiString: ...
	def Init(self, theFormatType: TCollection_HAsciiString) -> None: ...
	def SetFormatType(self, theFormatType: TCollection_HAsciiString) -> None: ...

class StepShape_ValueQualifier(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def PrecisionQualifier(self) -> StepShape_PrecisionQualifier: ...
	def TypeQualifier(self) -> StepShape_TypeQualifier: ...
	def ValueFormatTypeQualifier(self) -> StepShape_ValueFormatTypeQualifier: ...

class StepShape_AdvancedBrepShapeRepresentation(StepShape_ShapeRepresentation):
	def __init__(self) -> None: ...

class StepShape_AngularLocation(StepShape_DimensionalLocation):
	def __init__(self) -> None: ...
	def AngleSelection(self) -> StepShape_AngleRelator: ...
	def Init(self, aShapeAspectRelationship_Name: TCollection_HAsciiString, hasShapeAspectRelationship_Description: bool, aShapeAspectRelationship_Description: TCollection_HAsciiString, aShapeAspectRelationship_RelatingShapeAspect: StepRepr_ShapeAspect, aShapeAspectRelationship_RelatedShapeAspect: StepRepr_ShapeAspect, aAngleSelection: StepShape_AngleRelator) -> None: ...
	def SetAngleSelection(self, AngleSelection: StepShape_AngleRelator) -> None: ...

class StepShape_AngularSize(StepShape_DimensionalSize):
	def __init__(self) -> None: ...
	def AngleSelection(self) -> StepShape_AngleRelator: ...
	def Init(self, aDimensionalSize_AppliesTo: StepRepr_ShapeAspect, aDimensionalSize_Name: TCollection_HAsciiString, aAngleSelection: StepShape_AngleRelator) -> None: ...
	def SetAngleSelection(self, AngleSelection: StepShape_AngleRelator) -> None: ...

class StepShape_BoxedHalfSpace(StepShape_HalfSpaceSolid):
	def __init__(self) -> None: ...
	def Enclosure(self) -> StepShape_BoxDomain: ...
	def Init(self, aName: TCollection_HAsciiString, aBaseSurface: StepGeom_Surface, aAgreementFlag: bool, aEnclosure: StepShape_BoxDomain) -> None: ...
	def SetEnclosure(self, aEnclosure: StepShape_BoxDomain) -> None: ...

class StepShape_CompoundShapeRepresentation(StepShape_ShapeRepresentation):
	def __init__(self) -> None: ...

class StepShape_ConnectedEdgeSet(StepShape_TopologicalRepresentationItem):
	def __init__(self) -> None: ...
	def CesEdges(self) -> StepShape_HArray1OfEdge: ...
	def Init(self, aRepresentationItem_Name: TCollection_HAsciiString, aCesEdges: StepShape_HArray1OfEdge) -> None: ...
	def SetCesEdges(self, CesEdges: StepShape_HArray1OfEdge) -> None: ...

class StepShape_ConnectedFaceSet(StepShape_TopologicalRepresentationItem):
	def __init__(self) -> None: ...
	def CfsFaces(self) -> StepShape_HArray1OfFace: ...
	def CfsFacesValue(self, num: int) -> StepShape_Face: ...
	def Init(self, aName: TCollection_HAsciiString, aCfsFaces: StepShape_HArray1OfFace) -> None: ...
	def NbCfsFaces(self) -> int: ...
	def SetCfsFaces(self, aCfsFaces: StepShape_HArray1OfFace) -> None: ...

class StepShape_CsgShapeRepresentation(StepShape_ShapeRepresentation):
	def __init__(self) -> None: ...

class StepShape_CsgSolid(StepShape_SolidModel):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aTreeRootExpression: StepShape_CsgSelect) -> None: ...
	def SetTreeRootExpression(self, aTreeRootExpression: StepShape_CsgSelect) -> None: ...
	def TreeRootExpression(self) -> StepShape_CsgSelect: ...

class StepShape_DimensionalLocationWithPath(StepShape_DimensionalLocation):
	def __init__(self) -> None: ...
	def Init(self, aShapeAspectRelationship_Name: TCollection_HAsciiString, hasShapeAspectRelationship_Description: bool, aShapeAspectRelationship_Description: TCollection_HAsciiString, aShapeAspectRelationship_RelatingShapeAspect: StepRepr_ShapeAspect, aShapeAspectRelationship_RelatedShapeAspect: StepRepr_ShapeAspect, aPath: StepRepr_ShapeAspect) -> None: ...
	def Path(self) -> StepRepr_ShapeAspect: ...
	def SetPath(self, Path: StepRepr_ShapeAspect) -> None: ...

class StepShape_DimensionalSizeWithPath(StepShape_DimensionalSize):
	def __init__(self) -> None: ...
	def Init(self, aDimensionalSize_AppliesTo: StepRepr_ShapeAspect, aDimensionalSize_Name: TCollection_HAsciiString, aPath: StepRepr_ShapeAspect) -> None: ...
	def Path(self) -> StepRepr_ShapeAspect: ...
	def SetPath(self, Path: StepRepr_ShapeAspect) -> None: ...

class StepShape_DirectedDimensionalLocation(StepShape_DimensionalLocation):
	def __init__(self) -> None: ...

class StepShape_Edge(StepShape_TopologicalRepresentationItem):
	def __init__(self) -> None: ...
	def EdgeEnd(self) -> StepShape_Vertex: ...
	def EdgeStart(self) -> StepShape_Vertex: ...
	def Init(self, aName: TCollection_HAsciiString, aEdgeStart: StepShape_Vertex, aEdgeEnd: StepShape_Vertex) -> None: ...
	def SetEdgeEnd(self, aEdgeEnd: StepShape_Vertex) -> None: ...
	def SetEdgeStart(self, aEdgeStart: StepShape_Vertex) -> None: ...

class StepShape_EdgeBasedWireframeShapeRepresentation(StepShape_ShapeRepresentation):
	def __init__(self) -> None: ...

class StepShape_Face(StepShape_TopologicalRepresentationItem):
	def __init__(self) -> None: ...
	def Bounds(self) -> StepShape_HArray1OfFaceBound: ...
	def BoundsValue(self, num: int) -> StepShape_FaceBound: ...
	def Init(self, aName: TCollection_HAsciiString, aBounds: StepShape_HArray1OfFaceBound) -> None: ...
	def NbBounds(self) -> int: ...
	def SetBounds(self, aBounds: StepShape_HArray1OfFaceBound) -> None: ...

class StepShape_FaceBound(StepShape_TopologicalRepresentationItem):
	def __init__(self) -> None: ...
	def Bound(self) -> StepShape_Loop: ...
	def Init(self, aName: TCollection_HAsciiString, aBound: StepShape_Loop, aOrientation: bool) -> None: ...
	def Orientation(self) -> bool: ...
	def SetBound(self, aBound: StepShape_Loop) -> None: ...
	def SetOrientation(self, aOrientation: bool) -> None: ...

class StepShape_FacetedBrepShapeRepresentation(StepShape_ShapeRepresentation):
	def __init__(self) -> None: ...

class StepShape_GeometricCurveSet(StepShape_GeometricSet):
	def __init__(self) -> None: ...

class StepShape_GeometricallyBoundedSurfaceShapeRepresentation(StepShape_ShapeRepresentation):
	def __init__(self) -> None: ...

class StepShape_GeometricallyBoundedWireframeShapeRepresentation(StepShape_ShapeRepresentation):
	def __init__(self) -> None: ...

class StepShape_Loop(StepShape_TopologicalRepresentationItem):
	def __init__(self) -> None: ...

class StepShape_LoopAndPath(StepShape_TopologicalRepresentationItem):
	def __init__(self) -> None: ...
	def EdgeList(self) -> StepShape_HArray1OfOrientedEdge: ...
	def EdgeListValue(self, num: int) -> StepShape_OrientedEdge: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aLoop: StepShape_Loop, aPath: StepShape_Path) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aEdgeList: StepShape_HArray1OfOrientedEdge) -> None: ...
	def Loop(self) -> StepShape_Loop: ...
	def NbEdgeList(self) -> int: ...
	def Path(self) -> StepShape_Path: ...
	def SetEdgeList(self, aEdgeList: StepShape_HArray1OfOrientedEdge) -> None: ...
	def SetLoop(self, aLoop: StepShape_Loop) -> None: ...
	def SetPath(self, aPath: StepShape_Path) -> None: ...

class StepShape_ManifoldSolidBrep(StepShape_SolidModel):
	def __init__(self) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aOuter: StepShape_ClosedShell) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aOuter: StepShape_ConnectedFaceSet) -> None: ...
	def Outer(self) -> StepShape_ConnectedFaceSet: ...
	def SetOuter(self, aOuter: StepShape_ConnectedFaceSet) -> None: ...

class StepShape_ManifoldSurfaceShapeRepresentation(StepShape_ShapeRepresentation):
	def __init__(self) -> None: ...

class StepShape_NonManifoldSurfaceShapeRepresentation(StepShape_ShapeRepresentation):
	def __init__(self) -> None: ...

class StepShape_Path(StepShape_TopologicalRepresentationItem):
	def __init__(self) -> None: ...
	def EdgeList(self) -> StepShape_HArray1OfOrientedEdge: ...
	def EdgeListValue(self, num: int) -> StepShape_OrientedEdge: ...
	def Init(self, aName: TCollection_HAsciiString, aEdgeList: StepShape_HArray1OfOrientedEdge) -> None: ...
	def NbEdgeList(self) -> int: ...
	def SetEdgeList(self, aEdgeList: StepShape_HArray1OfOrientedEdge) -> None: ...

class StepShape_PointRepresentation(StepShape_ShapeRepresentation):
	def __init__(self) -> None: ...

class StepShape_ShapeDimensionRepresentation(StepShape_ShapeRepresentation):
	def __init__(self) -> None: ...
	@overload
	def Init(self, theName: TCollection_HAsciiString, theItems: StepRepr_HArray1OfRepresentationItem, theContextOfItems: StepRepr_RepresentationContext) -> None: ...
	@overload
	def Init(self, theName: TCollection_HAsciiString, theItems: StepShape_HArray1OfShapeDimensionRepresentationItem, theContextOfItems: StepRepr_RepresentationContext) -> None: ...
	def ItemsAP242(self) -> StepShape_HArray1OfShapeDimensionRepresentationItem: ...
	def SetItemsAP242(self, theItems: StepShape_HArray1OfShapeDimensionRepresentationItem) -> None: ...

class StepShape_ShapeRepresentationWithParameters(StepShape_ShapeRepresentation):
	def __init__(self) -> None: ...

class StepShape_SolidReplica(StepShape_SolidModel):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aParentSolid: StepShape_SolidModel, aTransformation: StepGeom_CartesianTransformationOperator3d) -> None: ...
	def ParentSolid(self) -> StepShape_SolidModel: ...
	def SetParentSolid(self, aParentSolid: StepShape_SolidModel) -> None: ...
	def SetTransformation(self, aTransformation: StepGeom_CartesianTransformationOperator3d) -> None: ...
	def Transformation(self) -> StepGeom_CartesianTransformationOperator3d: ...

class StepShape_SweptAreaSolid(StepShape_SolidModel):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aSweptArea: StepGeom_CurveBoundedSurface) -> None: ...
	def SetSweptArea(self, aSweptArea: StepGeom_CurveBoundedSurface) -> None: ...
	def SweptArea(self) -> StepGeom_CurveBoundedSurface: ...

class StepShape_SweptFaceSolid(StepShape_SolidModel):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aSweptArea: StepShape_FaceSurface) -> None: ...
	def SetSweptFace(self, aSweptArea: StepShape_FaceSurface) -> None: ...
	def SweptFace(self) -> StepShape_FaceSurface: ...

class StepShape_TransitionalShapeRepresentation(StepShape_ShapeRepresentation):
	def __init__(self) -> None: ...

class StepShape_Vertex(StepShape_TopologicalRepresentationItem):
	def __init__(self) -> None: ...

class StepShape_BrepWithVoids(StepShape_ManifoldSolidBrep):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aOuter: StepShape_ClosedShell, aVoids: StepShape_HArray1OfOrientedClosedShell) -> None: ...
	def NbVoids(self) -> int: ...
	def SetVoids(self, aVoids: StepShape_HArray1OfOrientedClosedShell) -> None: ...
	def Voids(self) -> StepShape_HArray1OfOrientedClosedShell: ...
	def VoidsValue(self, num: int) -> StepShape_OrientedClosedShell: ...

class StepShape_ClosedShell(StepShape_ConnectedFaceSet):
	def __init__(self) -> None: ...

class StepShape_ConnectedFaceSubSet(StepShape_ConnectedFaceSet):
	def __init__(self) -> None: ...
	def Init(self, aRepresentationItem_Name: TCollection_HAsciiString, aConnectedFaceSet_CfsFaces: StepShape_HArray1OfFace, aParentFaceSet: StepShape_ConnectedFaceSet) -> None: ...
	def ParentFaceSet(self) -> StepShape_ConnectedFaceSet: ...
	def SetParentFaceSet(self, ParentFaceSet: StepShape_ConnectedFaceSet) -> None: ...

class StepShape_EdgeCurve(StepShape_Edge):
	def __init__(self) -> None: ...
	def EdgeGeometry(self) -> StepGeom_Curve: ...
	def Init(self, aName: TCollection_HAsciiString, aEdgeStart: StepShape_Vertex, aEdgeEnd: StepShape_Vertex, aEdgeGeometry: StepGeom_Curve, aSameSense: bool) -> None: ...
	def SameSense(self) -> bool: ...
	def SetEdgeGeometry(self, aEdgeGeometry: StepGeom_Curve) -> None: ...
	def SetSameSense(self, aSameSense: bool) -> None: ...

class StepShape_EdgeLoop(StepShape_Loop):
	def __init__(self) -> None: ...
	def EdgeList(self) -> StepShape_HArray1OfOrientedEdge: ...
	def EdgeListValue(self, num: int) -> StepShape_OrientedEdge: ...
	def Init(self, aName: TCollection_HAsciiString, aEdgeList: StepShape_HArray1OfOrientedEdge) -> None: ...
	def NbEdgeList(self) -> int: ...
	def SetEdgeList(self, aEdgeList: StepShape_HArray1OfOrientedEdge) -> None: ...

class StepShape_ExtrudedAreaSolid(StepShape_SweptAreaSolid):
	def __init__(self) -> None: ...
	def Depth(self) -> float: ...
	def ExtrudedDirection(self) -> StepGeom_Direction: ...
	def Init(self, aName: TCollection_HAsciiString, aSweptArea: StepGeom_CurveBoundedSurface, aExtrudedDirection: StepGeom_Direction, aDepth: float) -> None: ...
	def SetDepth(self, aDepth: float) -> None: ...
	def SetExtrudedDirection(self, aExtrudedDirection: StepGeom_Direction) -> None: ...

class StepShape_ExtrudedFaceSolid(StepShape_SweptFaceSolid):
	def __init__(self) -> None: ...
	def Depth(self) -> float: ...
	def ExtrudedDirection(self) -> StepGeom_Direction: ...
	def Init(self, aName: TCollection_HAsciiString, aSweptArea: StepShape_FaceSurface, aExtrudedDirection: StepGeom_Direction, aDepth: float) -> None: ...
	def SetDepth(self, aDepth: float) -> None: ...
	def SetExtrudedDirection(self, aExtrudedDirection: StepGeom_Direction) -> None: ...

class StepShape_FaceOuterBound(StepShape_FaceBound):
	def __init__(self) -> None: ...

class StepShape_FaceSurface(StepShape_Face):
	def __init__(self) -> None: ...
	def FaceGeometry(self) -> StepGeom_Surface: ...
	def Init(self, aName: TCollection_HAsciiString, aBounds: StepShape_HArray1OfFaceBound, aFaceGeometry: StepGeom_Surface, aSameSense: bool) -> None: ...
	def SameSense(self) -> bool: ...
	def SetFaceGeometry(self, aFaceGeometry: StepGeom_Surface) -> None: ...
	def SetSameSense(self, aSameSense: bool) -> None: ...

class StepShape_FacetedBrep(StepShape_ManifoldSolidBrep):
	def __init__(self) -> None: ...

class StepShape_FacetedBrepAndBrepWithVoids(StepShape_ManifoldSolidBrep):
	def __init__(self) -> None: ...
	def BrepWithVoids(self) -> StepShape_BrepWithVoids: ...
	def FacetedBrep(self) -> StepShape_FacetedBrep: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aOuter: StepShape_ClosedShell, aFacetedBrep: StepShape_FacetedBrep, aBrepWithVoids: StepShape_BrepWithVoids) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aOuter: StepShape_ClosedShell, aVoids: StepShape_HArray1OfOrientedClosedShell) -> None: ...
	def NbVoids(self) -> int: ...
	def SetBrepWithVoids(self, aBrepWithVoids: StepShape_BrepWithVoids) -> None: ...
	def SetFacetedBrep(self, aFacetedBrep: StepShape_FacetedBrep) -> None: ...
	def SetVoids(self, aVoids: StepShape_HArray1OfOrientedClosedShell) -> None: ...
	def Voids(self) -> StepShape_HArray1OfOrientedClosedShell: ...
	def VoidsValue(self, num: int) -> StepShape_OrientedClosedShell: ...

class StepShape_OpenShell(StepShape_ConnectedFaceSet):
	def __init__(self) -> None: ...

class StepShape_OrientedEdge(StepShape_Edge):
	def __init__(self) -> None: ...
	def EdgeElement(self) -> StepShape_Edge: ...
	def EdgeEnd(self) -> StepShape_Vertex: ...
	def EdgeStart(self) -> StepShape_Vertex: ...
	def Init(self, aName: TCollection_HAsciiString, aEdgeElement: StepShape_Edge, aOrientation: bool) -> None: ...
	def Orientation(self) -> bool: ...
	def SetEdgeElement(self, aEdgeElement: StepShape_Edge) -> None: ...
	def SetEdgeEnd(self, aEdgeEnd: StepShape_Vertex) -> None: ...
	def SetEdgeStart(self, aEdgeStart: StepShape_Vertex) -> None: ...
	def SetOrientation(self, aOrientation: bool) -> None: ...

class StepShape_OrientedFace(StepShape_Face):
	def __init__(self) -> None: ...
	def Bounds(self) -> StepShape_HArray1OfFaceBound: ...
	def BoundsValue(self, num: int) -> StepShape_FaceBound: ...
	def FaceElement(self) -> StepShape_Face: ...
	def Init(self, aName: TCollection_HAsciiString, aFaceElement: StepShape_Face, aOrientation: bool) -> None: ...
	def NbBounds(self) -> int: ...
	def Orientation(self) -> bool: ...
	def SetBounds(self, aBounds: StepShape_HArray1OfFaceBound) -> None: ...
	def SetFaceElement(self, aFaceElement: StepShape_Face) -> None: ...
	def SetOrientation(self, aOrientation: bool) -> None: ...

class StepShape_OrientedPath(StepShape_Path):
	def __init__(self) -> None: ...
	def EdgeList(self) -> StepShape_HArray1OfOrientedEdge: ...
	def EdgeListValue(self, num: int) -> StepShape_OrientedEdge: ...
	def Init(self, aName: TCollection_HAsciiString, aPathElement: StepShape_EdgeLoop, aOrientation: bool) -> None: ...
	def NbEdgeList(self) -> int: ...
	def Orientation(self) -> bool: ...
	def PathElement(self) -> StepShape_EdgeLoop: ...
	def SetEdgeList(self, aEdgeList: StepShape_HArray1OfOrientedEdge) -> None: ...
	def SetOrientation(self, aOrientation: bool) -> None: ...
	def SetPathElement(self, aPathElement: StepShape_EdgeLoop) -> None: ...

class StepShape_PolyLoop(StepShape_Loop):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPolygon: StepGeom_HArray1OfCartesianPoint) -> None: ...
	def NbPolygon(self) -> int: ...
	def Polygon(self) -> StepGeom_HArray1OfCartesianPoint: ...
	def PolygonValue(self, num: int) -> StepGeom_CartesianPoint: ...
	def SetPolygon(self, aPolygon: StepGeom_HArray1OfCartesianPoint) -> None: ...

class StepShape_RevolvedAreaSolid(StepShape_SweptAreaSolid):
	def __init__(self) -> None: ...
	def Angle(self) -> float: ...
	def Axis(self) -> StepGeom_Axis1Placement: ...
	def Init(self, aName: TCollection_HAsciiString, aSweptArea: StepGeom_CurveBoundedSurface, aAxis: StepGeom_Axis1Placement, aAngle: float) -> None: ...
	def SetAngle(self, aAngle: float) -> None: ...
	def SetAxis(self, aAxis: StepGeom_Axis1Placement) -> None: ...

class StepShape_RevolvedFaceSolid(StepShape_SweptFaceSolid):
	def __init__(self) -> None: ...
	def Angle(self) -> float: ...
	def Axis(self) -> StepGeom_Axis1Placement: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aSweptArea: StepShape_FaceSurface) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aSweptArea: StepShape_FaceSurface, aAxis: StepGeom_Axis1Placement, aAngle: float) -> None: ...
	def SetAngle(self, aAngle: float) -> None: ...
	def SetAxis(self, aAxis: StepGeom_Axis1Placement) -> None: ...

class StepShape_Subedge(StepShape_Edge):
	def __init__(self) -> None: ...
	def Init(self, aRepresentationItem_Name: TCollection_HAsciiString, aEdge_EdgeStart: StepShape_Vertex, aEdge_EdgeEnd: StepShape_Vertex, aParentEdge: StepShape_Edge) -> None: ...
	def ParentEdge(self) -> StepShape_Edge: ...
	def SetParentEdge(self, ParentEdge: StepShape_Edge) -> None: ...

class StepShape_Subface(StepShape_Face):
	def __init__(self) -> None: ...
	def Init(self, aRepresentationItem_Name: TCollection_HAsciiString, aFace_Bounds: StepShape_HArray1OfFaceBound, aParentFace: StepShape_Face) -> None: ...
	def ParentFace(self) -> StepShape_Face: ...
	def SetParentFace(self, ParentFace: StepShape_Face) -> None: ...

class StepShape_VertexLoop(StepShape_Loop):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aLoopVertex: StepShape_Vertex) -> None: ...
	def LoopVertex(self) -> StepShape_Vertex: ...
	def SetLoopVertex(self, aLoopVertex: StepShape_Vertex) -> None: ...

class StepShape_VertexPoint(StepShape_Vertex):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aVertexGeometry: StepGeom_Point) -> None: ...
	def SetVertexGeometry(self, aVertexGeometry: StepGeom_Point) -> None: ...
	def VertexGeometry(self) -> StepGeom_Point: ...

class StepShape_AdvancedFace(StepShape_FaceSurface):
	def __init__(self) -> None: ...

class StepShape_OrientedClosedShell(StepShape_ClosedShell):
	def __init__(self) -> None: ...
	def CfsFaces(self) -> StepShape_HArray1OfFace: ...
	def CfsFacesValue(self, num: int) -> StepShape_Face: ...
	def ClosedShellElement(self) -> StepShape_ClosedShell: ...
	def Init(self, aName: TCollection_HAsciiString, aClosedShellElement: StepShape_ClosedShell, aOrientation: bool) -> None: ...
	def NbCfsFaces(self) -> int: ...
	def Orientation(self) -> bool: ...
	def SetCfsFaces(self, aCfsFaces: StepShape_HArray1OfFace) -> None: ...
	def SetClosedShellElement(self, aClosedShellElement: StepShape_ClosedShell) -> None: ...
	def SetOrientation(self, aOrientation: bool) -> None: ...

class StepShape_OrientedOpenShell(StepShape_OpenShell):
	def __init__(self) -> None: ...
	def CfsFaces(self) -> StepShape_HArray1OfFace: ...
	def CfsFacesValue(self, num: int) -> StepShape_Face: ...
	def Init(self, aName: TCollection_HAsciiString, aOpenShellElement: StepShape_OpenShell, aOrientation: bool) -> None: ...
	def NbCfsFaces(self) -> int: ...
	def OpenShellElement(self) -> StepShape_OpenShell: ...
	def Orientation(self) -> bool: ...
	def SetCfsFaces(self, aCfsFaces: StepShape_HArray1OfFace) -> None: ...
	def SetOpenShellElement(self, aOpenShellElement: StepShape_OpenShell) -> None: ...
	def SetOrientation(self, aOrientation: bool) -> None: ...

class StepShape_SeamEdge(StepShape_OrientedEdge):
	def __init__(self) -> None: ...
	def Init(self, aRepresentationItem_Name: TCollection_HAsciiString, aOrientedEdge_EdgeElement: StepShape_Edge, aOrientedEdge_Orientation: bool, aPcurveReference: StepGeom_Pcurve) -> None: ...
	def PcurveReference(self) -> StepGeom_Pcurve: ...
	def SetPcurveReference(self, PcurveReference: StepGeom_Pcurve) -> None: ...

# harray1 classes

class StepShape_HArray1OfConnectedEdgeSet(StepShape_Array1OfConnectedEdgeSet, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepShape_Array1OfConnectedEdgeSet: ...


class StepShape_HArray1OfFaceBound(StepShape_Array1OfFaceBound, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepShape_Array1OfFaceBound: ...


class StepShape_HArray1OfGeometricSetSelect(StepShape_Array1OfGeometricSetSelect, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepShape_Array1OfGeometricSetSelect: ...


class StepShape_HArray1OfConnectedFaceSet(StepShape_Array1OfConnectedFaceSet, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepShape_Array1OfConnectedFaceSet: ...


class StepShape_HArray1OfEdge(StepShape_Array1OfEdge, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepShape_Array1OfEdge: ...


class StepShape_HArray1OfFace(StepShape_Array1OfFace, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepShape_Array1OfFace: ...


class StepShape_HArray1OfShapeDimensionRepresentationItem(StepShape_Array1OfShapeDimensionRepresentationItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepShape_Array1OfShapeDimensionRepresentationItem: ...


class StepShape_HArray1OfValueQualifier(StepShape_Array1OfValueQualifier, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepShape_Array1OfValueQualifier: ...


class StepShape_HArray1OfShell(StepShape_Array1OfShell, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepShape_Array1OfShell: ...


class StepShape_HArray1OfOrientedClosedShell(StepShape_Array1OfOrientedClosedShell, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepShape_Array1OfOrientedClosedShell: ...


class StepShape_HArray1OfOrientedEdge(StepShape_Array1OfOrientedEdge, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepShape_Array1OfOrientedEdge: ...

# harray2 classes
# hsequence classes

